@@ -8,7 +8,7 @@ Pelix is a Python framework that aims to act as OSGi as much as possible
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.5.6
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -29,7 +29,7 @@ Pelix is a Python framework that aims to act as OSGi as much as possible
 """
 
 # Module version
-__version_info__ = (0, 5, 6)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -37,10 +37,9 @@ __docformat__ = "restructuredtext en"
 
 # ------------------------------------------------------------------------------
 
-# Wild import of constants (to stay compatible with previous version)
-from pelix.constants import *
-
-# Pelix beans
+# Pelix beans and constants
+from pelix.constants import ACTIVATOR, ACTIVATOR_LEGACY, FRAMEWORK_UID, \
+    BundleException, FrameworkException
 from pelix.internals.events import BundleEvent, ServiceEvent
 from pelix.internals.registry import EventDispatcher, ServiceRegistry, \
     ServiceReference, ServiceRegistration
@@ -51,6 +50,7 @@ from pelix.utilities import SynchronizedClassMethod, is_string
 # Standard library
 import imp
 import importlib
+import inspect
 import logging
 import os
 import pkgutil
@@ -65,6 +65,7 @@ _logger = logging.getLogger("pelix.main")
 
 # ------------------------------------------------------------------------------
 
+
 class Bundle(object):
     """
     Represents a "bundle" in Pelix
@@ -88,7 +89,6 @@ class Bundle(object):
     ACTIVE = 32
     """ The bundle is now running """
 
-
     def __init__(self, framework, bundle_id, name, module):
         """
         Sets up the bundle descriptor
@@ -114,14 +114,12 @@ class Bundle(object):
         self.__registered_services = []
         self.__registration_lock = threading.Lock()
 
-
     def __str__(self):
         """
         String representation
         """
         return "Bundle(ID={0}, Name={1})".format(self.__id, self.__name)
 
-
     def __get_activator_method(self, method_name):
         """
         Retrieves the requested method of the activator, or returns None
@@ -136,13 +134,12 @@ class Bundle(object):
             activator = getattr(self.__module, ACTIVATOR_LEGACY, None)
             if activator is not None:
                 # Old activator found: print a deprecation warning
-                _logger.warning("Bundle %s uses the deprecated '%s' to declare "
-                                "its activator. Use @BundleActivator instead.",
+                _logger.warning("Bundle %s uses the deprecated '%s' to declare"
+                                " its activator. "
+                                "Use @BundleActivator instead.",
                                 self.__name, ACTIVATOR_LEGACY)
-
         return getattr(activator, method_name, None)
 
-
     def _fire_bundle_event(self, kind):
         """
         Fires a bundle event of the given kind
@@ -151,7 +148,6 @@ class Bundle(object):
         """
         self.__framework._dispatcher.fire_bundle_event(BundleEvent(kind, self))
 
-
     def _registered_service(self, registration):
         """
         Bundle is notified by the framework that a service has been registered
@@ -162,11 +158,10 @@ class Bundle(object):
         with self.__registration_lock:
             self.__registered_services.append(registration)
 
-
     def _unregistered_service(self, registration):
         """
-        Bundle is notified by the framework that a service has been unregistered
-        in the name of this bundle.
+        Bundle is notified by the framework that a service has been
+        unregistered in the name of this bundle.
 
         :param registration: The service registration object
         """
@@ -174,7 +169,6 @@ class Bundle(object):
             if registration in self.__registered_services:
                 self.__registered_services.remove(registration)
 
-
     def get_bundle_context(self):
         """
         Retrieves the bundle context
@@ -183,7 +177,6 @@ class Bundle(object):
         """
         return self.__context
 
-
     def get_bundle_id(self):
         """
         Retrieves the bundle ID
@@ -192,7 +185,6 @@ class Bundle(object):
         """
         return self.__id
 
-
     def get_location(self):
         """
         Retrieves the location of this module
@@ -201,7 +193,6 @@ class Bundle(object):
         """
         return getattr(self.__module, '__file__', "")
 
-
     def get_module(self):
         """
         Retrieves the Python module corresponding to the bundle
@@ -210,15 +201,14 @@ class Bundle(object):
         """
         return self.__module
 
-
     def get_registered_services(self):
         """
         Returns this bundle's ServiceReference list for all services it has
         registered or an empty list
 
         The list is valid at the time of the call to this method, however, as
-        the Framework is a very dynamic environment, services can be modified or
-        unregistered at any time.
+        the Framework is a very dynamic environment, services can be modified
+        or unregistered at any time.
 
         :return: An array of ServiceReference objects
         :raise BundleException: If the bundle has been uninstalled
@@ -226,14 +216,12 @@ class Bundle(object):
         if self._state == Bundle.UNINSTALLED:
             raise BundleException("Can't call 'get_registered_services' on an "
                                   "uninstalled bundle")
-
         return self.__framework._registry.get_bundle_registered_services(self)
 
-
     def get_services_in_use(self):
         """
-        Returns this bundle's ServiceReference list for all services it is using
-        or an empty list.
+        Returns this bundle's ServiceReference list for all services it is
+        using or an empty list.
         A bundle is considered to be using a service if its use count for that
         service is greater than zero.
 
@@ -247,10 +235,8 @@ class Bundle(object):
         if self._state == Bundle.UNINSTALLED:
             raise BundleException("Can't call 'get_services_in_use' on an "
                                   "uninstalled bundle")
-
         return self.__framework._registry.get_bundle_imported_services(self)
 
-
     def get_state(self):
         """
         Retrieves the bundle state
@@ -259,7 +245,6 @@ class Bundle(object):
         """
         return self._state
 
-
     def get_symbolic_name(self):
         """
         Retrieves the bundle symbolic name (its Python module name)
@@ -268,7 +253,6 @@ class Bundle(object):
         """
         return self.__name
 
-
     def get_version(self):
         """
         Retrieves the bundle version, using the ``__version__`` or
@@ -289,7 +273,6 @@ class Bundle(object):
         # No version
         return "0.0.0"
 
-
     def start(self):
         """
         Starts the bundle. Does nothing if the bundle is already starting or
@@ -327,8 +310,8 @@ class Bundle(object):
                     self._state = previous_state
 
                     # Re-raise directly Pelix exceptions
-                    _logger.exception("Pelix error raised by %s while starting",
-                                      self.__name)
+                    _logger.exception("Pelix error raised by %s while "
+                                      "starting", self.__name)
                     raise
 
                 except Exception as ex:
@@ -344,7 +327,6 @@ class Bundle(object):
             self._state = Bundle.ACTIVE
             self._fire_bundle_event(BundleEvent.STARTED)
 
-
     def stop(self):
         """
         Stops the bundle. Does nothing if the bundle is already stopped.
@@ -376,8 +358,8 @@ class Bundle(object):
                     self._state = previous_state
 
                     # Re-raise directly Pelix exceptions
-                    _logger.exception("Pelix error raised by %s while stopping",
-                                      self.__name)
+                    _logger.exception("Pelix error raised by %s while "
+                                      "stopping", self.__name)
                     exception = ex
 
                 except Exception as ex:
@@ -398,10 +380,11 @@ class Bundle(object):
             self._fire_bundle_event(BundleEvent.STOPPED)
 
         # Raise the exception, if any
+        # pylint: disable=E0702
+        # Pylint seems to miss the "is not None" check below
         if exception is not None:
             raise exception
 
-
     def __unregister_services(self):
         """
         Unregisters all bundle services
@@ -425,7 +408,6 @@ class Bundle(object):
             # Clear the list, just to be clean
             del self.__registered_services[:]
 
-
     def uninstall(self):
         """
         Uninstalls the bundle
@@ -440,7 +422,6 @@ class Bundle(object):
             # Call the framework
             self.__framework.uninstall_bundle(self)
 
-
     @SynchronizedClassMethod('_lock')
     def update(self):
         """
@@ -461,36 +442,45 @@ class Bundle(object):
             raise
 
         # Change the source file age
-        time_changed = False
+        module_stat = None
         module_file = getattr(self.__module, "__file__", None)
         if module_file is not None and os.path.isfile(module_file):
             try:
-                stat = os.stat(module_file)
-
-                # Change modification time to bypass weak time resolution of the
-                # underlying file system
-                os.utime(module_file, (stat.st_atime, stat.st_mtime + 1))
-                time_changed = True
+                module_stat = os.stat(module_file)
 
+                # Change modification time to bypass weak time resolution of
+                # the underlying file system
+                os.utime(module_file, (module_stat.st_atime,
+                                       module_stat.st_mtime + 1))
             except OSError:
                 # Can't touch the file
                 _logger.warning("Failed to update the modification time of "
-                                "'%s'. The bundle update might not reflect the "
-                                "latest changes.", module_file)
+                                "'%s'. The bundle update might not reflect the"
+                                " latest changes.", module_file)
+
+        # Clean up the module constants (otherwise kept by reload)
+        # Keep special members (__name__, __file__, ...)
+        old_content = self.__module.__dict__.copy()
+        for name in tuple(self.__module.__dict__):
+            if not (name.startswith('__') and name.endswith('__')):
+                del self.__module.__dict__[name]
 
         try:
             # Reload the module
             imp.reload(self.__module)
-
-        except SyntaxError as ex:
-            # Exception raised in Python 3
+        except (ImportError, SyntaxError) as ex:
+            # Exception raised if the file is unreadable
             _logger.exception("Error updating %s: %s", self.__name, ex)
 
-        if time_changed:
+            # Reset module content
+            self.__module.__dict__.clear()
+            self.__module.__dict__.update(old_content)
+
+        if module_stat is not None:
             try:
                 # Reset times
-                os.utime(module_file, (stat.st_atime, stat.st_mtime))
-
+                os.utime(module_file, (module_stat.st_atime,
+                                       module_stat.st_mtime))
             except OSError:
                 # Shouldn't occur, since we succeeded before the update
                 _logger.debug("Failed to reset the modification time of '%s'",
@@ -510,6 +500,7 @@ class Bundle(object):
 
 # ------------------------------------------------------------------------------
 
+
 class Framework(Bundle):
     """
     The Pelix framework (main) class. It must be instantiated using
@@ -563,7 +554,6 @@ class Framework(Bundle):
         self._fw_stop_event = threading.Event()
         self._fw_stop_event.set()
 
-
     def add_property(self, name, value):
         """
         Adds a property to the framework **if it is not yet set**.
@@ -583,7 +573,6 @@ class Framework(Bundle):
             self.__properties[name] = value
             return True
 
-
     def find_service_references(self, clazz=None, ldap_filter=None,
                                 only_one=False):
         """
@@ -593,12 +582,12 @@ class Framework(Bundle):
         :param ldap_filter: Service filter
         :param only_one: Return the first matching service reference only
         :return: A list of found reference, or None
-        :raise BundleException: An error occurred looking for service references
+        :raise BundleException: An error occurred looking for service
+                                references
         """
         return self._registry.find_service_references(clazz, ldap_filter,
                                                       only_one)
 
-
     def get_bundle_by_id(self, bundle_id):
         """
         Retrieves the bundle with the given ID
@@ -613,11 +602,11 @@ class Framework(Bundle):
 
         with self.__bundles_lock:
             if bundle_id not in self.__bundles:
-                raise BundleException("Invalid bundle ID {0}".format(bundle_id))
+                raise BundleException("Invalid bundle ID {0}"
+                                      .format(bundle_id))
 
             return self.__bundles[bundle_id]
 
-
     def get_bundle_by_name(self, bundle_name):
         """
         Retrieves the bundle with the given name
@@ -642,7 +631,6 @@ class Framework(Bundle):
             # Not found...
             return None
 
-
     def get_bundles(self):
         """
         Returns the list of all installed bundles
@@ -652,7 +640,6 @@ class Framework(Bundle):
         with self.__bundles_lock:
             return list(self.__bundles.values())
 
-
     def get_properties(self):
         """
         Retrieves a copy of the stored framework properties.
@@ -660,7 +647,6 @@ class Framework(Bundle):
         with self.__properties_lock:
             return self.__properties.copy()
 
-
     def get_property(self, name):
         """
         Retrieves a framework or system property. As framework properties don't
@@ -671,7 +657,6 @@ class Framework(Bundle):
         with self.__properties_lock:
             return self.__properties.get(name, os.getenv(name))
 
-
     def get_property_keys(self):
         """
         Returns an array of the keys in the properties of the service
@@ -681,7 +666,6 @@ class Framework(Bundle):
         with self.__properties_lock:
             return tuple(self.__properties.keys())
 
-
     def get_service(self, bundle, reference):
         """
         Retrieves the service corresponding to the given reference
@@ -696,7 +680,8 @@ class Framework(Bundle):
             raise TypeError("First argument must be a Bundle object")
 
         if not isinstance(reference, ServiceReference):
-            raise TypeError("Second argument must be a ServiceReference object")
+            raise TypeError("Second argument must be a ServiceReference "
+                            "object")
 
         if reference in self.__unregistering_services:
             # Unregistering service, just give it
@@ -704,7 +689,6 @@ class Framework(Bundle):
 
         return self._registry.get_service(bundle, reference)
 
-
     def get_symbolic_name(self):
         """
         Retrieves the framework symbolic name
@@ -713,13 +697,12 @@ class Framework(Bundle):
         """
         return "pelix.framework"
 
-
     def install_bundle(self, name, path=None):
         """
         Installs the bundle with the given name
 
-        *Note:* Before Pelix 0.5.0, this method returned the ID of the installed
-        bundle, instead of the Bundle object.
+        *Note:* Before Pelix 0.5.0, this method returned the ID of the
+        installed bundle, instead of the Bundle object.
 
         **WARNING:** The behavior of the loading process is subject to changes,
         as it does not allow to safely run multiple frameworks in the same
@@ -752,12 +735,10 @@ class Framework(Bundle):
                     #  __import__(name) -> package level
                     # import_module -> module level
                     module = importlib.import_module(name)
-
             except ImportError as ex:
                 # Error importing the module
-                raise BundleException("Error installing bundle {0}: {1}" \
+                raise BundleException("Error installing bundle {0}: {1}"
                                       .format(name, ex))
-
             finally:
                 if path:
                     # Clean up the path. The loaded module(s) might
@@ -783,10 +764,8 @@ class Framework(Bundle):
         # Fire the bundle installed event
         event = BundleEvent(BundleEvent.INSTALLED, bundle)
         self._dispatcher.fire_bundle_event(event)
-
         return bundle
 
-
     def install_package(self, path, recursive=False, prefix=None):
         """
         Installs all the modules found in the given package
@@ -844,7 +823,6 @@ class Framework(Bundle):
 
         return bundles, failed
 
-
     def install_visiting(self, path, visitor, prefix=None):
         """
         Installs all the modules found in the given path if they are accepted
@@ -888,8 +866,8 @@ class Framework(Bundle):
 
         with self.__bundles_lock:
             # Use an ImpImporter per iteration because, in Python 3,
-            # pkgutil.iter_modules() will use a _FileImporter on the second walk
-            # in a package which will return nothing
+            # pkgutil.iter_modules() will use a _FileImporter on the second
+            # walk in a package which will return nothing
             for name, is_package in pkgutil.ImpImporter(path).iter_modules():
                 # Compute the full name of the module
                 fullname = '.'.join((prefix, name)) if prefix else name
@@ -902,10 +880,9 @@ class Framework(Bundle):
 
                             # Visit the package
                             sub_path = os.path.join(path, name)
-                            sub_bundles, sub_failed = self.install_visiting(
-                                                                sub_path,
-                                                                visitor,
-                                                                fullname)
+                            sub_bundles, sub_failed = \
+                                self.install_visiting(sub_path, visitor,
+                                                      fullname)
                             bundles.update(sub_bundles)
                             failed.update(sub_failed)
 
@@ -923,7 +900,6 @@ class Framework(Bundle):
 
         return bundles, failed
 
-
     def register_service(self, bundle, clazz, service, properties, send_event):
         """
         Registers a service and calls the listeners
@@ -961,7 +937,7 @@ class Framework(Bundle):
 
             if not svc_clazz or not is_string(svc_clazz):
                 # Invalid class name
-                raise BundleException("Invalid class name: {0}" \
+                raise BundleException("Invalid class name: {0}"
                                       .format(svc_clazz))
 
             # Class OK
@@ -982,7 +958,6 @@ class Framework(Bundle):
 
         return registration
 
-
     @SynchronizedClassMethod('_lock')
     def start(self):
         """
@@ -1011,7 +986,8 @@ class Framework(Bundle):
 
             except FrameworkException as ex:
                 # Important error
-                _logger.exception("Important error starting bundle: %s", bundle)
+                _logger.exception("Important error starting bundle: %s",
+                                  bundle)
                 if ex.needs_stop:
                     # Stop the framework (has to be in active state)
                     self._state = Bundle.ACTIVE
@@ -1026,9 +1002,8 @@ class Framework(Bundle):
         self._state = Bundle.ACTIVE
         return True
 
-
     @SynchronizedClassMethod('_lock')
-    def stop(self, force=False):
+    def stop(self):
         """
         Stops the framework
 
@@ -1073,10 +1048,8 @@ class Framework(Bundle):
 
         # Force the registry clean up
         self._registry.clear()
-
         return True
 
-
     def uninstall(self):
         """
         A framework can't be uninstalled
@@ -1085,7 +1058,6 @@ class Framework(Bundle):
         """
         raise BundleException("A framework can't be uninstalled")
 
-
     def uninstall_bundle(self, bundle):
         """
         Ends the uninstallation of the given bundle (must be called by Bundle)
@@ -1106,20 +1078,18 @@ class Framework(Bundle):
                 raise BundleException("Invalid bundle {0}".format(bundle))
 
             # Notify listeners
-            self._dispatcher.fire_bundle_event(BundleEvent(
-                                                       BundleEvent.UNINSTALLED,
-                                                       bundle))
+            self._dispatcher.fire_bundle_event(
+                BundleEvent(BundleEvent.UNINSTALLED, bundle))
 
             # Remove it from the dictionary
             del self.__bundles[bundle_id]
 
-            # Remove it from the system => avoid unintended behaviors and forces
-            # a complete module reload if it is re-installed
+            # Remove it from the system => avoid unintended behaviors and
+            # forces a complete module reload if it is re-installed
             name = bundle.get_symbolic_name()
             if name in sys.modules:
                 del sys.modules[name]
 
-
     def unregister_service(self, registration):
         """
         Unregisters the given service
@@ -1148,10 +1118,8 @@ class Framework(Bundle):
 
         # Remove the unregistering reference
         del self.__unregistering_services[reference]
-
         return True
 
-
     def update(self):
         """
         Stops and starts the framework, if the framework is active.
@@ -1164,7 +1132,6 @@ class Framework(Bundle):
                 self.stop()
                 self.start()
 
-
     def wait_for_stop(self, timeout=None):
         """
         Waits for the framework to stop. Does nothing if the framework bundle
@@ -1187,6 +1154,7 @@ class Framework(Bundle):
 
 # ------------------------------------------------------------------------------
 
+
 class BundleContext(object):
     """
     Represents a bundle context
@@ -1201,14 +1169,12 @@ class BundleContext(object):
         self.__bundle = bundle
         self.__framework = framework
 
-
     def __str__(self):
         """
         String representation
         """
         return "BundleContext({0})".format(self.__bundle)
 
-
     def add_bundle_listener(self, listener):
         """
         Registers a bundle listener
@@ -1219,7 +1185,7 @@ class BundleContext(object):
 
            def bundle_changed(self, bundle_event):
                '''
-               :param bundle_event: A BundleEvent object
+               bundle_event: A BundleEvent object
                '''
                # ...
 
@@ -1228,13 +1194,12 @@ class BundleContext(object):
         """
         return self.__framework._dispatcher.add_bundle_listener(listener)
 
-
     def add_framework_stop_listener(self, listener):
         """
-        Registers a listener that will be called back right before the framework
-        stops
+        Registers a listener that will be called back right before the
+        framework stops
 
-        The framework listener must have a method with the following prototype :
+        The framework listener must have a method with the following prototype:
 
         .. python::
 
@@ -1249,13 +1214,12 @@ class BundleContext(object):
         """
         return self.__framework._dispatcher.add_framework_listener(listener)
 
-
     def add_service_listener(self, listener, ldap_filter=None,
                              specification=None):
         """
         Registers a service listener
 
-        The service listener must have a method with the following prototype :
+        The service listener must have a method with the following prototype:
 
         .. python::
 
@@ -1263,7 +1227,7 @@ class BundleContext(object):
                '''
                Called by Pelix when some service properties changes
 
-               :param event: A ServiceEvent object
+               event: A ServiceEvent object
                '''
                # ...
 
@@ -1278,13 +1242,12 @@ class BundleContext(object):
                                                                  specification,
                                                                  ldap_filter)
 
-
     def get_all_service_references(self, clazz, ldap_filter=None):
         """
         Returns an array of ServiceReference objects.
         The returned array of ServiceReference objects contains services that
-        were registered under the specified class and match the specified filter
-        expression.
+        were registered under the specified class and match the specified
+        filter expression.
 
         :param clazz: Class implemented by the service
         :param ldap_filter: Service filter
@@ -1292,7 +1255,6 @@ class BundleContext(object):
         """
         return self.__framework.find_service_references(clazz, ldap_filter)
 
-
     def get_bundle(self, bundle_id=None):
         """
         Retrieves the bundle with the given ID. If no ID is given (None).
@@ -1304,14 +1266,12 @@ class BundleContext(object):
         if bundle_id is None:
             # Current bundle
             return self.__bundle
-
         elif type(bundle_id) is Bundle:
             # Got a bundle (compatibility with older install_bundle())
             bundle_id = bundle_id.get_bundle_id()
 
         return self.__framework.get_bundle_by_id(bundle_id)
 
-
     def get_bundles(self):
         """
         Returns the list of all installed bundles
@@ -1320,7 +1280,6 @@ class BundleContext(object):
         """
         return self.__framework.get_bundles()
 
-
     def get_property(self, name):
         """
         Returns the value of a property of the framework, else returns the OS
@@ -1330,7 +1289,6 @@ class BundleContext(object):
         """
         return self.__framework.get_property(name)
 
-
     def get_service(self, reference):
         """
         Returns the service described with the given reference
@@ -1340,7 +1298,6 @@ class BundleContext(object):
         """
         return self.__framework.get_service(self.__bundle, reference)
 
-
     def get_service_reference(self, clazz, ldap_filter=None):
         """
         Returns a ServiceReference object for a service that implements and \
@@ -1353,7 +1310,6 @@ class BundleContext(object):
         return self.__framework.find_service_references(clazz, ldap_filter,
                                                         True)
 
-
     def get_service_references(self, clazz, ldap_filter=None):
         """
         Returns the service references for services that were registered under
@@ -1372,13 +1328,12 @@ class BundleContext(object):
 
         return refs
 
-
     def install_bundle(self, name, path=None):
         """
         Installs the bundle with the given name
 
-        *Note:* Before Pelix 0.5.0, this method returned the ID of the installed
-        bundle, instead of the Bundle object.
+        *Note:* Before Pelix 0.5.0, this method returned the ID of the
+        installed bundle, instead of the Bundle object.
 
         **WARNING:** The behavior of the loading process is subject to changes,
         as it does not allow to safely run multiple frameworks in the same
@@ -1391,7 +1346,6 @@ class BundleContext(object):
         """
         return self.__framework.install_bundle(name, path)
 
-
     def install_package(self, path, recursive=False):
         """
         Installs all the modules found in the given package
@@ -1404,7 +1358,6 @@ class BundleContext(object):
         """
         return self.__framework.install_package(path, recursive)
 
-
     def install_visiting(self, path, visitor):
         """
         Installs all the modules found in the given path if they are accepted
@@ -1424,7 +1377,6 @@ class BundleContext(object):
         """
         return self.__framework.install_visiting(path, visitor)
 
-
     def register_service(self, clazz, service, properties, send_event=True):
         """
         Registers a service
@@ -1437,8 +1389,8 @@ class BundleContext(object):
         :raise BundleException: An error occurred while registering the service
         """
         return self.__framework.register_service(self.__bundle, clazz,
-                                                service, properties, send_event)
-
+                                                 service, properties,
+                                                 send_event)
 
     def remove_bundle_listener(self, listener):
         """
@@ -1449,7 +1401,6 @@ class BundleContext(object):
         """
         return self.__framework._dispatcher.remove_bundle_listener(listener)
 
-
     def remove_framework_stop_listener(self, listener):
         """
         Unregisters a framework stop listener
@@ -1459,7 +1410,6 @@ class BundleContext(object):
         """
         return self.__framework._dispatcher.remove_framework_listener(listener)
 
-
     def remove_service_listener(self, listener):
         """
         Unregisters a service listener
@@ -1469,7 +1419,6 @@ class BundleContext(object):
         """
         return self.__framework._dispatcher.remove_service_listener(listener)
 
-
     def unget_service(self, reference):
         """
         Disables a reference to the service
@@ -1482,11 +1431,11 @@ class BundleContext(object):
 
 # ------------------------------------------------------------------------------
 
+
 class FrameworkFactory(object):
     """
     A framework factory
     """
-
     __singleton = None
     """ The framework singleton """
 
@@ -1503,7 +1452,6 @@ class FrameworkFactory(object):
 
         return cls.__singleton
 
-
     @classmethod
     def is_framework_running(cls, framework=None):
         """
@@ -1516,11 +1464,9 @@ class FrameworkFactory(object):
         """
         if framework is None:
             return cls.__singleton is not None
-
         else:
             return cls.__singleton == framework
 
-
     @classmethod
     def delete_framework(cls, framework):
         """
@@ -1532,7 +1478,6 @@ class FrameworkFactory(object):
             # Stop the framework
             try:
                 framework.stop()
-
             except:
                 _logger.exception("Error stopping the framework")
 
@@ -1542,7 +1487,7 @@ class FrameworkFactory(object):
                 try:
                     bundle.uninstall()
                 except:
-                    _logger.exception("Error uninstalling bundle %s", \
+                    _logger.exception("Error uninstalling bundle %s",
                                       bundle.get_symbolic_name())
 
             # Clear the event dispatcher
@@ -1556,6 +1501,7 @@ class FrameworkFactory(object):
 
 # ------------------------------------------------------------------------------
 
+
 def create_framework(bundles, properties=None,
                      auto_start=False, wait_for_stop=False, auto_delete=False):
     """
@@ -1565,8 +1511,8 @@ def create_framework(bundles, properties=None,
     will have been installed
     If *wait_for_stop* is True, the method will return only when the framework
     will have stopped. This requires *auto_start* to be True.
-    If *auto_delete* is True, the framework will be deleted once it has stopped,
-    and the method will return None.
+    If *auto_delete* is True, the framework will be deleted once it has
+    stopped, and the method will return None.
     This requires *wait_for_stop* and *auto_start* to be True.
 
     :param bundles: Bundles to initially install (shouldn't be empty if
