@@ -9,7 +9,7 @@ Python library.
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.1.5
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -30,7 +30,7 @@ Python library.
 """
 
 # Module version
-__version_info__ = (0, 1, 5)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -43,6 +43,7 @@ from pelix.ipopo.decorators import ComponentFactory, Provides, Validate, \
     Invalidate, Property, Requires, BindField, UnbindField, UpdateField
 
 import pelix.ipopo.constants as constants
+import pelix.ipv6utils
 import pelix.utilities as utilities
 
 # Standard library
@@ -54,6 +55,7 @@ import traceback
 # Basic HTTP server
 try:
     # Python 3
+    # pylint: disable=F0401,E0611
     import urllib.parse as urlparse
     from http.server import HTTPServer
     from http.server import BaseHTTPRequestHandler
@@ -61,6 +63,7 @@ try:
 
 except ImportError:
     # Python 2
+    # pylint: disable=F0401
     import urlparse
     from BaseHTTPServer import HTTPServer
     from BaseHTTPServer import BaseHTTPRequestHandler
@@ -76,6 +79,7 @@ HTTP_SERVICE_EXTRA = "http.extra"
 
 # ------------------------------------------------------------------------------
 
+
 class _HTTPServletRequest(http.AbstractHTTPServletRequest):
     """
     HTTP Servlet request helper
@@ -88,7 +92,6 @@ class _HTTPServletRequest(http.AbstractHTTPServletRequest):
         """
         self._handler = request_handler
 
-
     def get_client_address(self):
         """
         Retrieves the address of the client
@@ -97,28 +100,24 @@ class _HTTPServletRequest(http.AbstractHTTPServletRequest):
         """
         return self._handler.client_address
 
-
     def get_header(self, name, default=None):
         """
         Retrieves the value of a header
         """
         return self._handler.headers.get(name, default)
 
-
     def get_headers(self):
         """
         Retrieves all headers
         """
         return self._handler.headers
 
-
     def get_path(self):
         """
         Retrieves the request full path
         """
         return self._handler.path
 
-
     def get_rfile(self):
         """
         Retrieves the input as a file stream
@@ -138,7 +137,6 @@ class _HTTPServletResponse(http.AbstractHTTPServletResponse):
         """
         self._handler = request_handler
 
-
     def set_response(self, code, message=None):
         """
         Sets the response line.
@@ -149,7 +147,6 @@ class _HTTPServletResponse(http.AbstractHTTPServletResponse):
         """
         self._handler.send_response(code, message)
 
-
     def set_header(self, name, value):
         """
         Sets the value of a header.
@@ -160,14 +157,12 @@ class _HTTPServletResponse(http.AbstractHTTPServletResponse):
         """
         self._handler.send_header(name, value)
 
-
     def end_headers(self):
         """
         Ends the headers part
         """
         self._handler.end_headers()
 
-
     def get_wfile(self):
         """
         Retrieves the output as a file stream.
@@ -178,7 +173,6 @@ class _HTTPServletResponse(http.AbstractHTTPServletResponse):
         """
         return self._handler.wfile
 
-
     def write(self, data):
         """
         Writes the given data.
@@ -191,7 +185,8 @@ class _HTTPServletResponse(http.AbstractHTTPServletResponse):
 
 # ------------------------------------------------------------------------------
 
-class _RequestHandler(BaseHTTPRequestHandler):
+
+class _RequestHandler(BaseHTTPRequestHandler, object):
     """
     Basic HTTP server request handler
     """
@@ -209,7 +204,6 @@ class _RequestHandler(BaseHTTPRequestHandler):
         # This calls the do_* methods
         BaseHTTPRequestHandler.__init__(self, *args, **kwargs)
 
-
     def __getattr__(self, name):
         """
         Retrieves the do_* in the servlet corresponding to the request path.
@@ -223,8 +217,11 @@ class _RequestHandler(BaseHTTPRequestHandler):
             # Not a request handling
             return object.__getattribute__(self, name)
 
+        # Remove double-slashes in path
+        path = self.path.replace('//', '/')
+
         # Parse the URL
-        parsed_url = urlparse.urlparse(self.path)
+        parsed_url = urlparse.urlparse(path)
         parsed_path = parsed_url.path
 
         # Get the corresponding servlet
@@ -244,7 +241,6 @@ class _RequestHandler(BaseHTTPRequestHandler):
                     try:
                         # Handle the request
                         return getattr(servlet, name)(request, response)
-
                     except:
                         # Send a 500 error page on error
                         return self.send_exception(response)
@@ -255,21 +251,18 @@ class _RequestHandler(BaseHTTPRequestHandler):
         # Return the super implementation if needed
         return self.send_no_servlet_response
 
-
     def log_error(self, message, *args, **kwargs):
         """
         Log server error
         """
         self._service.log(logging.ERROR, message, *args, **kwargs)
 
-
     def log_request(self, code='-', size='-'):
         """
         Logs a request to the server
         """
         self._service.log(logging.DEBUG, '"%s" %s', self.requestline, code)
 
-
     def send_no_servlet_response(self):
         """
         Default response sent when no servlet is found for the requested path
@@ -288,7 +281,6 @@ class _RequestHandler(BaseHTTPRequestHandler):
         response = _HTTPServletResponse(self)
         response.send_content(404, page)
 
-
     def send_exception(self, response):
         """
         Sends an exception page with a 500 error code.
@@ -322,6 +314,7 @@ class _RequestHandler(BaseHTTPRequestHandler):
 
 # ------------------------------------------------------------------------------
 
+
 class _HttpServerFamily(ThreadingMixIn, HTTPServer):
     """
     A small modification to have a threaded HTTP Server with a custom address
@@ -346,38 +339,31 @@ class _HttpServerFamily(ThreadingMixIn, HTTPServer):
         # Get the family of the first possibility
         self.address_family = addr_info[0][0]
 
-        # Special case: IPv6
-        ipv6 = (self.address_family == socket.AF_INET6)
-
         # Set up the server, socket, ... but do not bind immediately
         HTTPServer.__init__(self, server_address, request_handler_class, False)
 
-        if ipv6:
+        if self.address_family == socket.AF_INET6:
             # Explicitly ask to be accessible both by IPv4 and IPv6
-            # Some versions of Python don't have V6ONLY.
-            # On Linux, IPC6_V6ONLY = 26
-            opt_ipv6_only = getattr(socket, "IPV6_V6ONLY", 26)
-
             try:
-                self.socket.setsockopt(socket.IPPROTO_IPV6, opt_ipv6_only, 0)
-
-            except socket.error as ex:
-                # Ignore the error, but log it if possible
+                pelix.ipv6utils.set_double_stack(self.socket)
+            except AttributeError as ex:
                 if logger is not None:
-                    logger.exception("Couldn't set IP double stack flag: %s",
+                    logger.exception("System misses IPv6 constant: %s", ex)
+            except socket.error as ex:
+                if logger is not None:
+                    logger.exception("Error setting up IPv6 double stack: %s",
                                      ex)
 
         # Bind & accept
         self.server_bind()
         self.server_activate()
 
-
     def process_request(self, request, client_address):
         """
         Starts a new thread to process the request, adding the client address
         in its name.
         """
-        thread = threading.Thread(name="HttpService-{0}-Client-{1}"\
+        thread = threading.Thread(name="HttpService-{0}-Client-{1}"
                                   .format(self.server_port, client_address),
                                   target=self.process_request_thread,
                                   args=(request, client_address))
@@ -386,6 +372,7 @@ class _HttpServerFamily(ThreadingMixIn, HTTPServer):
 
 # ------------------------------------------------------------------------------
 
+
 @ComponentFactory(http.FACTORY_HTTP_BASIC)
 @Provides(http.HTTP_SERVICE)
 @Requires("_servlets_services", http.HTTP_SERVLET, True, True)
@@ -434,14 +421,12 @@ class HttpService(object):
         self._server = None
         self._thread = None
 
-
     def __str__(self):
         """
         String representation of the instance
         """
         return "BasicHttpService({0}, {1:d})".format(self._address, self._port)
 
-
     def __safe_callback(self, instance, method, *args, **kwargs):
         """
         Safely calls the given method in the given instance.
@@ -476,7 +461,6 @@ class HttpService(object):
 
         return False
 
-
     def __register_servlet_service(self, service, service_reference):
         """
         Registers a servlet according to its service properties
@@ -495,7 +479,6 @@ class HttpService(object):
             for path in paths:
                 self.register_servlet(path, service, None)
 
-
     @BindField("_servlets_services")
     def _bind(self, field, service, service_reference):
         """
@@ -508,7 +491,6 @@ class HttpService(object):
                 # We've been validated, register the service
                 self.__register_servlet_service(service, service_reference)
 
-
     @UpdateField('_servlets_services')
     def _update(self, field, service, service_reference, old_properties):
         """
@@ -529,7 +511,6 @@ class HttpService(object):
                 # Register the service with its new properties
                 self.__register_servlet_service(service, service_reference)
 
-
     @UnbindField("_servlets_services")
     def _unbind(self, field, service, service_reference):
         """
@@ -542,7 +523,6 @@ class HttpService(object):
             # Remove the service reference
             del self._servlets_refs[service]
 
-
     def get_access(self):
         """
         Retrieves the (address, port) tuple to access the server
@@ -552,7 +532,6 @@ class HttpService(object):
         # Only keep the address and the port information
         return sock_info[0], sock_info[1]
 
-
     def get_hostname(self):
         """
         Retrieves the server host name
@@ -561,7 +540,6 @@ class HttpService(object):
         """
         return socket.gethostname()
 
-
     def get_servlet(self, path):
         """
         Retrieves the servlet matching the given path and its parameters.
@@ -584,7 +562,6 @@ class HttpService(object):
         with self._lock:
             longest_match = ""
             for servlet_path in self._servlets.keys():
-
                 tested_path = servlet_path
                 if tested_path[-1] != '/':
                     # Add a trailing slash
@@ -605,7 +582,6 @@ class HttpService(object):
                 # Retrieve the stored information
                 return self._servlets[longest_match]
 
-
     def register_servlet(self, path, servlet, parameters=None):
         """
         Registers a servlet
@@ -621,7 +597,7 @@ class HttpService(object):
             raise ValueError("Invalid servlet instance")
 
         if not path or path[0] != '/':
-            raise ValueError("Invalid path given to register the servlet: {0}" \
+            raise ValueError("Invalid path given to register the servlet: {0}"
                              .format(path))
 
         # Use lower-case paths
@@ -661,7 +637,7 @@ class HttpService(object):
 
             if already_taken:
                 # The path is already taken by another servlet
-                raise ValueError("A servlet is already registered on {0}" \
+                raise ValueError("A servlet is already registered on {0}"
                                  .format(path))
 
             # Tell the servlet it can be bound to the path
@@ -673,7 +649,6 @@ class HttpService(object):
             # The servlet refused the binding
             return False
 
-
     def unregister(self, path, servlet=None):
         """
         Unregisters the servlet for the given path
@@ -687,13 +662,14 @@ class HttpService(object):
         if servlet is not None:
             with self._lock:
                 # Unregister all paths for this servlet
-                paths = [path
-                         for (path, servlet_info) in self._servlets.items()
+                paths = [servlet_path
+                         for (servlet_path, servlet_info)
+                         in self._servlets.items()
                          if servlet_info[0] == servlet]
 
             result = False
-            for path in paths:
-                result |= self.unregister(path)
+            for servlet_path in paths:
+                result |= self.unregister(servlet_path)
 
             return result
 
@@ -719,7 +695,6 @@ class HttpService(object):
                 del self._servlets[path]
                 return True
 
-
     def log(self, level, message, *args, **kwargs):
         """
         Logs the given message
@@ -731,7 +706,6 @@ class HttpService(object):
             # Log the message
             self._logger.log(level, message, *args, **kwargs)
 
-
     def log_exception(self, message, *args, **kwargs):
         """
         Logs an exception
@@ -742,7 +716,6 @@ class HttpService(object):
             # Log the exception
             self._logger.exception(message, *args, **kwargs)
 
-
     @Validate
     def validate(self, context):
         """
@@ -755,7 +728,6 @@ class HttpService(object):
         if self._port is None or self._port < 0:
             # Random port
             self._port = 0
-
         else:
             # Ensure we have an integer
             self._port = int(self._port)
@@ -791,8 +763,8 @@ class HttpService(object):
 
         # Run it in a separate thread
         self._thread = threading.Thread(target=self._server.serve_forever,
-                                        name="HttpService-{0}-Server" \
-                                             .format(self._port))
+                                        name="HttpService-{0}-Server"
+                                        .format(self._port))
         self._thread.daemon = True
         self._thread.start()
 
@@ -807,7 +779,6 @@ class HttpService(object):
         self.log(logging.INFO, "HTTP server started: [%s]:%d",
                  self._address, self._port)
 
-
     @Invalidate
     def invalidate(self, context):
         """
