@@ -6,7 +6,7 @@ Service registry and event dispatcher for Pelix.
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.5.6
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -27,7 +27,7 @@ Service registry and event dispatcher for Pelix.
 """
 
 # Module version
-__version_info__ = (0, 5, 6)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -51,6 +51,7 @@ import threading
 
 # ------------------------------------------------------------------------------
 
+
 class _UsageCounter(object):
     """
     Simple reference usage counter
@@ -61,14 +62,12 @@ class _UsageCounter(object):
         """
         self.__count = 0
 
-
     def inc(self):
         """
         Counter is incremented
         """
         self.__count += 1
 
-
     def dec(self):
         """
         Counter is decremented
@@ -78,7 +77,6 @@ class _UsageCounter(object):
         self.__count -= 1
         return self.__count > 0
 
-
     def is_used(self):
         """
         Tests if the reference is still used
@@ -89,6 +87,7 @@ class _UsageCounter(object):
 
 # ------------------------------------------------------------------------------
 
+
 class ServiceReference(object):
     """
     Represents a reference to a service
@@ -99,14 +98,15 @@ class ServiceReference(object):
 
         :param bundle: The bundle registering the service
         :param properties: The service properties
-        :raise BundleException: The properties doesn't contain mandatory entries
+        :raise BundleException: The properties doesn't contain mandatory
+                                entries
         """
         # Check properties
         for mandatory in (SERVICE_ID, OBJECTCLASS):
             if mandatory not in properties:
                 raise BundleException(
-                            "A Service must at least have a '{0}' entry"\
-                            .format(mandatory))
+                    "A Service must at least have a '{0}' entry"
+                    .format(mandatory))
 
         # Properties lock (used by ServiceRegistration too)
         self._props_lock = threading.RLock()
@@ -126,16 +126,13 @@ class ServiceReference(object):
         self.__sort_key = None
         self.update_sort_key()
 
-
     def __str__(self):
         """
         String representation
         """
-        return "ServiceReference(ID={0}, Bundle={1}, Specs={2})".format(
-                                                self.__service_id,
-                                                self.__bundle.get_bundle_id(),
-                                                self.__properties[OBJECTCLASS])
-
+        return "ServiceReference(ID={0}, Bundle={1}, Specs={2})" \
+            .format(self.__service_id, self.__bundle.get_bundle_id(),
+                    self.__properties[OBJECTCLASS])
 
     def __hash__(self):
         """
@@ -145,14 +142,12 @@ class ServiceReference(object):
         """
         return self.__service_id
 
-
     def __eq__(self, other):
         """
         Two references are equal if they have the same service ID
         """
         return self.__service_id == other.__service_id
 
-
     def __lt__(self, other):
         """
         Lesser than other
@@ -183,7 +178,6 @@ class ServiceReference(object):
         """
         return self.__service_id != other.__service_id
 
-
     def get_bundle(self):
         """
         Returns the bundle that registered this service
@@ -192,7 +186,6 @@ class ServiceReference(object):
         """
         return self.__bundle
 
-
     def get_using_bundles(self):
         """
         Returns the list of bundles that use this service
@@ -201,7 +194,6 @@ class ServiceReference(object):
         """
         return list(self.__using_bundles.keys())
 
-
     def get_properties(self):
         """
         Returns a copy of the service properties
@@ -211,7 +203,6 @@ class ServiceReference(object):
         with self._props_lock:
             return self.__properties.copy()
 
-
     def get_property(self, name):
         """
         Retrieves the property value for the given name
@@ -221,7 +212,6 @@ class ServiceReference(object):
         with self._props_lock:
             return self.__properties.get(name, None)
 
-
     def get_property_keys(self):
         """
         Returns an array of the keys in the properties of the service
@@ -231,7 +221,6 @@ class ServiceReference(object):
         with self._props_lock:
             return tuple(self.__properties.keys())
 
-
     def unused_by(self, bundle):
         """
         Indicates that this reference is not being used anymore by the given
@@ -250,12 +239,10 @@ class ServiceReference(object):
                     # This bundle has cleaner all of its usages of this
                     # reference
                     del self.__using_bundles[bundle]
-
             except KeyError:
                 # Ignore error
                 pass
 
-
     def used_by(self, bundle):
         """
         Indicates that this reference is being used by the given bundle.
@@ -270,18 +257,19 @@ class ServiceReference(object):
         with self.__usage_lock:
             self.__using_bundles.setdefault(bundle, _UsageCounter()).inc()
 
-
     def update_sort_key(self):
         """
         Recomputes the sort key, based on the service ranking and ID
 
-        See: http://www.osgi.org/javadoc/r4v43/org/osgi/framework/ServiceReference.html#compareTo%28java.lang.Object%29
+        See: http://www.osgi.org/javadoc/r4v43/org/osgi/framework/
+                          ServiceReference.html#compareTo%28java.lang.Object%29
         """
         self.__sort_key = (int(self.__properties.get(SERVICE_RANKING, 0)),
                            (-self.__service_id))
 
 # ------------------------------------------------------------------------------
 
+
 class ServiceRegistration(object):
     """
     Represents a service registration object
@@ -299,14 +287,12 @@ class ServiceRegistration(object):
         self.__reference = reference
         self.__properties = properties
 
-
     def __str__(self):
         """
         String representation
         """
         return "ServiceRegistration({0})".format(self.__reference)
 
-
     def get_reference(self):
         """
         Returns the reference associated to this registration
@@ -315,7 +301,6 @@ class ServiceRegistration(object):
         """
         return self.__reference
 
-
     def set_properties(self, properties):
         """
         Updates the service properties
@@ -362,16 +347,15 @@ class ServiceRegistration(object):
 
             self.__framework._dispatcher.fire_service_event(event)
 
-
     def unregister(self):
         """
         Unregisters the service
         """
         self.__framework.unregister_service(self)
 
-
 # ------------------------------------------------------------------------------
 
+
 class _Listener(object):
     """
     Keeps information about a listener
@@ -419,7 +403,6 @@ class EventDispatcher(object):
         self.__fw_listeners = []
         self.__fw_lock = threading.Lock()
 
-
     def clear(self):
         """
         Clears the event dispatcher
@@ -433,7 +416,6 @@ class EventDispatcher(object):
         with self.__fw_lock:
             del self.__fw_listeners[:]
 
-
     def add_bundle_listener(self, listener):
         """
         Adds a bundle listener
@@ -448,18 +430,17 @@ class EventDispatcher(object):
 
         with self.__bnd_lock:
             if listener in self.__bnd_listeners:
-                self._logger.warning("Already known bundle listener '%s'",
-                                listener)
+                self._logger.warning(
+                    "Already known bundle listener '%s'", listener)
                 return False
 
             self.__bnd_listeners.append(listener)
             return True
 
-
     def add_framework_listener(self, listener):
         """
-        Registers a listener that will be called back right before the framework
-        stops.
+        Registers a listener that will be called back right before the
+        framework stops.
 
         :param listener: The framework stop listener
         :return: True if the listener has been registered, False if it was
@@ -471,14 +452,13 @@ class EventDispatcher(object):
 
         with self.__fw_lock:
             if listener in self.__fw_listeners:
-                self._logger.warning("Already known framework listener '%s'",
-                                listener)
+                self._logger.warning(
+                    "Already known framework listener '%s'", listener)
                 return False
 
             self.__fw_listeners.append(listener)
             return True
 
-
     def add_service_listener(self, listener, specification=None,
                              ldap_filter=None):
         """
@@ -498,23 +478,22 @@ class EventDispatcher(object):
 
         with self.__svc_lock:
             if listener in self.__listeners_data:
-                self._logger.warning("Already known service listener '%s'",
-                                listener)
+                self._logger.warning(
+                    "Already known service listener '%s'", listener)
                 return False
 
             try:
                 ldap_filter = ldapfilter.get_ldap_filter(ldap_filter)
 
             except ValueError as ex:
-                raise BundleException("Invalid service filter: {0}" \
-                                                 .format(ex))
+                raise BundleException("Invalid service filter: {0}"
+                                      .format(ex))
 
             stored = _Listener(listener, specification, ldap_filter)
             self.__listeners_data[listener] = stored
             self.__svc_listeners.setdefault(specification, []).append(stored)
             return True
 
-
     def remove_bundle_listener(self, listener):
         """
         Unregisters a bundle listener
@@ -529,7 +508,6 @@ class EventDispatcher(object):
             self.__bnd_listeners.remove(listener)
             return True
 
-
     def remove_framework_listener(self, listener):
         """
         Unregisters a framework stop listener
@@ -544,7 +522,6 @@ class EventDispatcher(object):
             self.__fw_listeners.remove(listener)
             return True
 
-
     def remove_service_listener(self, listener):
         """
         Unregisters a service listener
@@ -564,7 +541,6 @@ class EventDispatcher(object):
             except KeyError:
                 return False
 
-
     def fire_bundle_event(self, event):
         """
         Notifies bundle events listeners of a new event in the calling thread.
@@ -582,7 +558,6 @@ class EventDispatcher(object):
             except:
                 self._logger.exception("Error calling a bundle listener")
 
-
     def fire_framework_stopping(self):
         """
         Calls all framework listeners, telling them that the framework is
@@ -597,10 +572,9 @@ class EventDispatcher(object):
                 listener.framework_stopping()
 
             except:
-                self._logger.exception("An error occurred calling one of the " \
+                self._logger.exception("An error occurred calling one of the "
                                        "framework stop listeners")
 
-
     def fire_service_event(self, event):
         """
         Notifies service events listeners of a new event in the calling thread.
@@ -644,10 +618,10 @@ class EventDispatcher(object):
             # Test if the service properties matches the filter
             ldap_filter = data.ldap_filter
             if ldap_filter is not None \
-            and not ldap_filter.matches(properties):
+                    and not ldap_filter.matches(properties):
                 # Event doesn't match listener filter...
                 if svc_modified and previous is not None \
-                and ldap_filter.matches(previous):
+                        and ldap_filter.matches(previous):
                     # ... but previous properties did match
                     sent_event = endmatch_event
                 else:
@@ -663,6 +637,7 @@ class EventDispatcher(object):
 
 # ------------------------------------------------------------------------------
 
+
 class ServiceRegistry(object):
     """
     Service registry for Pelix.
@@ -703,7 +678,6 @@ class ServiceRegistry(object):
         # Locks
         self.__svc_lock = threading.Lock()
 
-
     def clear(self):
         """
         Clears the registry
@@ -715,7 +689,6 @@ class ServiceRegistry(object):
             self.__bundle_svc.clear()
             self.__bundle_imports.clear()
 
-
     def register(self, bundle, classes, properties, svc_instance):
         """
         Registers a service.
@@ -754,7 +727,6 @@ class ServiceRegistry(object):
 
             return svc_registration
 
-
     def unregister(self, svc_ref):
         """
         Unregisters a service
@@ -791,7 +763,6 @@ class ServiceRegistry(object):
 
             return service
 
-
     def find_service_references(self, clazz=None, ldap_filter=None,
                                 only_one=False):
         """
@@ -801,7 +772,8 @@ class ServiceRegistry(object):
         :param ldap_filter: Service filter
         :param only_one: Return the first matching service reference only
         :return: A list of found references, or None
-        :raise BundleException: An error occurred looking for service references
+        :raise BundleException: An error occurred looking for service
+                                references
         """
         with self.__svc_lock:
             if clazz is None and ldap_filter is None:
@@ -855,11 +827,10 @@ class ServiceRegistry(object):
             # Get all the matching references
             return list(refs_set) or None
 
-
     def get_bundle_imported_services(self, bundle):
         """
-        Returns this bundle's ServiceReference list for all services it is using
-        or returns None if this bundle is not using any services.
+        Returns this bundle's ServiceReference list for all services it is
+        using or returns None if this bundle is not using any services.
         A bundle is considered to be using a service if its use count for that
         service is greater than zero.
 
@@ -873,7 +844,6 @@ class ServiceRegistry(object):
         with self.__svc_lock:
             return self.__bundle_imports.get(bundle, [])
 
-
     def get_bundle_registered_services(self, bundle):
         """
         Retrieves the services registered by the given bundle. Returns None
@@ -885,7 +855,6 @@ class ServiceRegistry(object):
         with self.__svc_lock:
             return self.__bundle_svc.get(bundle, [])
 
-
     def get_service(self, bundle, reference):
         """
         Retrieves the service corresponding to the given reference
@@ -909,10 +878,9 @@ class ServiceRegistry(object):
 
             except KeyError:
                 # Not found
-                raise BundleException("Service not found (reference: {0})" \
+                raise BundleException("Service not found (reference: {0})"
                                       .format(reference))
 
-
     def unget_service(self, bundle, reference):
         """
         Removes the usage of a service by a bundle
