@@ -6,7 +6,7 @@ Core iPOPO implementation
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.5.6
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -27,7 +27,7 @@ Core iPOPO implementation
 """
 
 # Module version
-__version_info__ = (0, 5, 6)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -68,6 +68,7 @@ BUILTIN_HANDLERS = ('pelix.ipopo.handlers.properties',
 
 # ------------------------------------------------------------------------------
 
+
 def _set_factory_context(factory_class, bundle_context):
     """
     Transforms the context data dictionary into its FactoryContext object form.
@@ -127,6 +128,7 @@ def _load_bundle_factories(bundle):
 
 # ------------------------------------------------------------------------------
 
+
 class _IPopoService(object):
     """
     The iPOPO registry and service
@@ -169,24 +171,22 @@ class _IPopoService(object):
         self.__waiting_handlers = {}
 
         # Register the service listener
-        bundle_context.add_service_listener(self, None,
-                                handlers_const.SERVICE_IPOPO_HANDLER_FACTORY)
+        bundle_context.add_service_listener(
+            self, None, handlers_const.SERVICE_IPOPO_HANDLER_FACTORY)
         self.__find_handler_factories()
 
-
     def __find_handler_factories(self):
         """
         Finds all registered handler factories and stores them
         """
         # Get the references
         svc_refs = self.__context.get_all_service_references(
-                                 handlers_const.SERVICE_IPOPO_HANDLER_FACTORY)
+            handlers_const.SERVICE_IPOPO_HANDLER_FACTORY)
         if svc_refs:
             for svc_ref in svc_refs:
                 # Store each handler factory
                 self.__add_handler_factory(svc_ref)
 
-
     def __add_handler_factory(self, svc_ref):
         """
         Stores a new handler factory
@@ -201,16 +201,16 @@ class _IPopoService(object):
                 # Duplicated ID
                 _logger.warning("Already registered handler ID: %s",
                                 handler_id)
-
             else:
                 # Store the service
                 self._handlers_refs.add(svc_ref)
-                self._handlers[handler_id] = self.__context.get_service(svc_ref)
+                self._handlers[handler_id] = \
+                    self.__context.get_service(svc_ref)
 
                 # Try to instantiate waiting components
                 succeeded = set()
                 for name, (context, instance) \
-                in self.__waiting_handlers.items():
+                        in self.__waiting_handlers.items():
                     if self.__try_instantiate(context, instance):
                         succeeded.add(name)
 
@@ -218,7 +218,6 @@ class _IPopoService(object):
                 for name in succeeded:
                     del self.__waiting_handlers[name]
 
-
     def __remove_handler_factory(self, svc_ref):
         """
         Removes an handler factory
@@ -261,14 +260,11 @@ class _IPopoService(object):
 
             # Try to find a new handler factory
             new_ref = self.__context.get_service_reference(
-                                handlers_const.SERVICE_IPOPO_HANDLER_FACTORY,
-                                "({0}={1})"\
-                                .format(handlers_const.PROP_HANDLER_ID,
-                                        handler_id))
+                handlers_const.SERVICE_IPOPO_HANDLER_FACTORY,
+                "({0}={1})".format(handlers_const.PROP_HANDLER_ID, handler_id))
             if new_ref is not None:
                 self.__add_handler_factory(new_ref)
 
-
     def __get_factory_with_context(self, factory_name):
         """
         Retrieves the factory registered with the given and its factory context
@@ -279,19 +275,18 @@ class _IPopoService(object):
         """
         factory = self.__factories.get(factory_name)
         if factory is None:
-            raise TypeError("Unknown factory '{0}'" \
+            raise TypeError("Unknown factory '{0}'"
                             .format(factory_name))
 
         # Get the factory context
         factory_context = getattr(factory, constants.IPOPO_FACTORY_CONTEXT,
                                   None)
         if factory_context is None:
-            raise TypeError("Factory context missing in '{0}'" \
+            raise TypeError("Factory context missing in '{0}'"
                             .format(factory_name))
 
         return factory, factory_context
 
-
     def __get_handler_factories(self, handlers_ids):
         """
         Returns the list of Handler Factories for the given Handlers IDs.
@@ -308,7 +303,6 @@ class _IPopoService(object):
 
         return handler_factories
 
-
     def __get_stored_instances(self, factory_name):
         """
         Retrieves the list of all stored instances objects corresponding to
@@ -318,11 +312,10 @@ class _IPopoService(object):
         :return: All components instantiated from the given factory
         """
         with self.__instances_lock:
-            return [stored_instance \
-                    for stored_instance in self.__instances.values() \
+            return [stored_instance
+                    for stored_instance in self.__instances.values()
                     if stored_instance.factory_name == factory_name]
 
-
     def __try_instantiate(self, component_context, instance):
         """
         Instantiates a component, if all of its handlers are there. Returns
@@ -343,7 +336,6 @@ class _IPopoService(object):
             try:
                 # Get handlers
                 handler_factories = self.__get_handler_factories(handlers_ids)
-
             except KeyError:
                 # A handler is missing, stop here
                 return False
@@ -379,10 +371,10 @@ class _IPopoService(object):
         stored_instance.check_lifecycle()
         return True
 
-
     def _autorestart_store_components(self, bundle):
         """
-        Stores the components of the given bundle with the auto-restart property
+        Stores the components of the given bundle with the auto-restart
+        property
 
         :param bundle: A Bundle object
         """
@@ -404,7 +396,6 @@ class _IPopoService(object):
                         store.append((factory, stored_instance.name,
                                       properties))
 
-
     def _autorestart_components(self, bundle):
         """
         Restart the components of the given bundle
@@ -412,7 +403,6 @@ class _IPopoService(object):
         :param bundle: A Bundle object
         """
         with self.__instances_lock:
-
             instances = self.__auto_restart.get(bundle)
             if not instances:
                 # Nothing to do
@@ -422,7 +412,6 @@ class _IPopoService(object):
                 try:
                     # Instantiate the given component
                     self.instantiate(factory, name, properties)
-
                 except Exception as ex:
                     # Log error, but continue to work
                     _logger.exception("Error restarting component '%s' ('%s')"
@@ -430,7 +419,6 @@ class _IPopoService(object):
                                       bundle.get_symbolic_name(),
                                       bundle.get_bundle_id(), ex)
 
-
     def _autorestart_clear_components(self, bundle):
         """
         Clear the list of auto-restart components of the given bundle
@@ -442,7 +430,6 @@ class _IPopoService(object):
             if bundle in self.__auto_restart:
                 del self.__auto_restart[bundle]
 
-
     def _fire_ipopo_event(self, kind, factory_name, instance_name=None):
         """
         Triggers an iPOPO event
@@ -458,14 +445,11 @@ class _IPopoService(object):
 
         for listener in listeners:
             try:
-                listener.handle_ipopo_event(constants.IPopoEvent(kind,
-                                                                 factory_name,
-                                                                 instance_name))
-
+                listener.handle_ipopo_event(
+                    constants.IPopoEvent(kind, factory_name, instance_name))
             except:
                 _logger.exception("Error calling an iPOPO event handler")
 
-
     def _prepare_instance_properties(self, properties, factory_properties):
         """
         Prepares the properties of a component instance, based on its
@@ -491,7 +475,6 @@ class _IPopoService(object):
 
         return properties
 
-
     def _register_bundle_factories(self, bundle):
         """
         Registers all factories found in the given bundle
@@ -507,19 +490,16 @@ class _IPopoService(object):
             try:
                 # Register each found factory
                 self._register_factory(context.name, factory_class, False)
-
             except ValueError as ex:
                 # Already known factory
-                _logger.error("Cannot register factory '%s' of bundle %d (%s): "
-                              "%s", context.name, bundle.get_bundle_id(),
+                _logger.error("Cannot register factory '%s' of bundle %d (%s):"
+                              " %s", context.name, bundle.get_bundle_id(),
                               bundle.get_symbolic_name(), ex)
-
             else:
                 # Instantiate components
                 for name, properties in context.get_instances().items():
                     self.instantiate(context.name, name, properties)
 
-
     def _register_factory(self, factory_name, factory, override):
         """
         Registers a component factory
@@ -527,8 +507,8 @@ class _IPopoService(object):
         :param factory_name: The name of the factory
         :param factory: The factory class object
         :param override: If true, previous factory is overridden, else an
-                         exception is risen if a previous factory with that name
-                         already exists
+                         exception is risen if a previous factory with that
+                         name already exists
         :raise ValueError: The factory name already exists or is invalid
         :raise TypeError: Invalid factory type
         """
@@ -536,8 +516,8 @@ class _IPopoService(object):
             raise ValueError("A factory name must be a non-empty string")
 
         if not inspect.isclass(factory):
-            raise TypeError("Invalid factory class '{0}'".format(
-                                                        type(factory).__name__))
+            raise TypeError("Invalid factory class '{0}'"
+                            .format(type(factory).__name__))
 
         with self.__factories_lock:
             if factory_name in self.__factories:
@@ -545,8 +525,8 @@ class _IPopoService(object):
                     _logger.info("Overriding factory '%s'", factory_name)
 
                 else:
-                    raise ValueError("'{0}' factory already exist".format(
-                                                                factory_name))
+                    raise ValueError("'{0}' factory already exist"
+                                     .format(factory_name))
 
             self.__factories[factory_name] = factory
 
@@ -554,7 +534,6 @@ class _IPopoService(object):
             self._fire_ipopo_event(constants.IPopoEvent.REGISTERED,
                                    factory_name)
 
-
     def _unregister_all_factories(self):
         """
         Unregisters all factories. This method should be called only after the
@@ -565,7 +544,6 @@ class _IPopoService(object):
         for factory_name in factories:
             self.unregister_factory(factory_name)
 
-
     def _unregister_bundle_factories(self, bundle):
         """
         Unregisters all factories of the given bundle
@@ -589,7 +567,6 @@ class _IPopoService(object):
                     _logger.warning("Error unregistering factory '%s': %s",
                                     factory_name, ex)
 
-
     def _stop(self):
         """
         iPOPO is stopping: clean everything up
@@ -608,14 +585,12 @@ class _IPopoService(object):
             self._handlers.clear()
             self._handlers_refs.clear()
 
-
     def framework_stopping(self):
         """
         Called by the framework when it is about to stop
         """
         self._stop()
 
-
     def bundle_changed(self, event):
         """
         A bundle event has been triggered
@@ -652,7 +627,6 @@ class _IPopoService(object):
             # Update failed, clean the stored components
             self._autorestart_clear_components(bundle)
 
-
     def service_changed(self, event):
         """
         Called when a handler factory service is un/registered
@@ -671,7 +645,6 @@ class _IPopoService(object):
             with self.__instances_lock:
                 self.__remove_handler_factory(svc_ref)
 
-
     def instantiate(self, factory_name, name, properties=None):
         """
         Instantiates a component from the given factory, with the given name
@@ -697,31 +670,30 @@ class _IPopoService(object):
 
         with self.__instances_lock:
             if name in self.__instances or name in self.__waiting_handlers:
-                raise ValueError("'{0}' is an already running instance name" \
+                raise ValueError("'{0}' is an already running instance name"
                                  .format(name))
 
             with self.__factories_lock:
                 # Can raise a TypeError exception
-                factory, factory_context = self.__get_factory_with_context(
-                                                                   factory_name)
+                factory, factory_context = \
+                    self.__get_factory_with_context(factory_name)
 
             # Create component instance
             try:
                 instance = factory()
-
             except:
-                _logger.exception("Error creating the instance '%s' " \
+                _logger.exception("Error creating the instance '%s' "
                                   "from factory '%s'", name, factory_name)
-
-                raise TypeError("Factory '{0}' failed to create '{1}'" \
+                raise TypeError("Factory '{0}' failed to create '{1}'"
                                 .format(factory_name, name))
 
             # Normalize the given properties
-            properties = self._prepare_instance_properties(properties,
-                                                   factory_context.properties)
+            properties = \
+                self._prepare_instance_properties(properties,
+                                                  factory_context.properties)
 
             # Set up the component instance context
-            component_context = ComponentContext(factory_context, name, \
+            component_context = ComponentContext(factory_context, name,
                                                  properties)
 
         # Try to instantiate the component immediately
@@ -731,7 +703,6 @@ class _IPopoService(object):
 
         return instance
 
-
     def invalidate(self, name):
         """
         Invalidates the given component
@@ -741,7 +712,7 @@ class _IPopoService(object):
         """
         with self.__instances_lock:
             if name not in self.__instances:
-                raise ValueError("Unknown component instance '{0}'"\
+                raise ValueError("Unknown component instance '{0}'"
                                  .format(name))
 
             stored_instance = self.__instances[name]
@@ -749,7 +720,6 @@ class _IPopoService(object):
             # Call back the component during the invalidation
             stored_instance.invalidate(True)
 
-
     def is_registered_factory(self, name):
         """
         Tests if the given name is in the factory registry
@@ -759,7 +729,6 @@ class _IPopoService(object):
         with self.__factories_lock:
             return name in self.__factories
 
-
     def is_registered_instance(self, name):
         """
         Tests if the given name is in the instance registry or in the waiting
@@ -770,7 +739,6 @@ class _IPopoService(object):
         with self.__instances_lock:
             return name in self.__instances
 
-
     def kill(self, name):
         """
         Kills the given component
@@ -793,12 +761,10 @@ class _IPopoService(object):
                 # Queued instance
                 try:
                     del self.__waiting_handlers[name]
-
                 except KeyError:
-                    raise ValueError("Unknown component instance '{0}'" \
+                    raise ValueError("Unknown component instance '{0}'"
                                      .format(name))
 
-
     def register_factory(self, bundle_context, factory):
         """
         Registers a manually created factory, using decorators programmatically
@@ -820,7 +786,6 @@ class _IPopoService(object):
         self._register_factory(context.name, factory, False)
         return True
 
-
     def unregister_factory(self, factory_name):
         """
         Unregisters the given component factory
@@ -865,8 +830,8 @@ class _IPopoService(object):
 
                 # Remove waiting component
                 names = [name
-                         for name, (context, _) \
-                                            in self.__waiting_handlers.items()
+                         for name, (context, _)
+                         in self.__waiting_handlers.items()
                          if context.factory_context.name == factory_name]
                 for name in names:
                     del self.__waiting_handlers[name]
@@ -876,7 +841,6 @@ class _IPopoService(object):
 
         return True
 
-
     def add_listener(self, listener):
         """
         Register an iPOPO event listener.
@@ -887,7 +851,7 @@ class _IPopoService(object):
 
            def handle_ipopo_event(self, event):
                '''
-               :param event: A IPopoEvent object
+               event: A IPopoEvent object
                '''
                # ...
 
@@ -897,7 +861,6 @@ class _IPopoService(object):
         with self.__listeners_lock:
             return add_listener(self.__listeners, listener)
 
-
     def remove_listener(self, listener):
         """
         Unregister an iPOPO event listener.
@@ -908,7 +871,6 @@ class _IPopoService(object):
         with self.__listeners_lock:
             return remove_listener(self.__listeners, listener)
 
-
     def get_instances(self):
         """
         Retrieves the list of the currently registered component instances
@@ -918,8 +880,8 @@ class _IPopoService(object):
         with self.__instances_lock:
             return sorted((name, stored_instance.factory_name,
                            stored_instance.state)
-                          for name, stored_instance in self.__instances.items())
-
+                          for name, stored_instance
+                          in self.__instances.items())
 
     def get_waiting_components(self):
         """
@@ -939,7 +901,6 @@ class _IPopoService(object):
             result.sort()
             return result
 
-
     def get_instance_details(self, name):
         """
         Retrieves a snapshot of the given component instance.
@@ -987,8 +948,8 @@ class _IPopoService(object):
                 result["factory"] = stored_instance.factory_name
 
                 # Factory bundle
-                result["bundle_id"] = stored_instance.bundle_context \
-                                                .get_bundle().get_bundle_id()
+                result["bundle_id"] = \
+                    stored_instance.bundle_context.get_bundle().get_bundle_id()
 
                 # Component state
                 result["state"] = stored_instance.state
@@ -996,7 +957,7 @@ class _IPopoService(object):
                 # Provided service
                 result["services"] = {}
                 for handler in stored_instance.get_handlers(
-                                        handlers_const.KIND_SERVICE_PROVIDER):
+                        handlers_const.KIND_SERVICE_PROVIDER):
                     svc_ref = handler.get_service_reference()
                     if svc_ref is not None:
                         svc_id = svc_ref.get_property(SERVICE_ID)
@@ -1005,7 +966,7 @@ class _IPopoService(object):
                 # Dependencies
                 result["dependencies"] = {}
                 for dependency in stored_instance.get_handlers(
-                                        handlers_const.KIND_DEPENDENCY):
+                        handlers_const.KIND_DEPENDENCY):
                     # Dependency
                     info = result["dependencies"][dependency.get_field()] = {}
                     info["handler"] = type(dependency).__name__
@@ -1030,7 +991,6 @@ class _IPopoService(object):
                 # All done
                 return result
 
-
     def get_factories(self):
         """
         Retrieves the names of the registered factories
@@ -1042,7 +1002,6 @@ class _IPopoService(object):
             result.sort()
             return result
 
-
     def get_factory_bundle(self, name):
         """
         Retrieves the Pelix Bundle object that registered the given factory
@@ -1061,7 +1020,6 @@ class _IPopoService(object):
             factory_context = getattr(factory, constants.IPOPO_FACTORY_CONTEXT)
             return factory_context.bundle_context.get_bundle()
 
-
     def get_factory_details(self, name):
         """
         Retrieves a dictionary with details about the given factory
@@ -1110,17 +1068,11 @@ class _IPopoService(object):
             handler_requires = context.get_handler(constants.HANDLER_REQUIRES)
             if handler_requires is not None:
                 for field, requirement in handler_requires.items():
-                    req = {}
-                    # ID = Field name
-                    req["id"] = field
-                    req["specification"] = requirement.specification
-                    req["aggregate"] = requirement.aggregate
-                    req["optional"] = requirement.optional
-
-                    # Give the string representation of the original LDAP filter
-                    req["filter"] = requirement.original_filter
-
-                    reqs.append(req)
+                    reqs.append({"id": field,
+                                 "specification": requirement.specification,
+                                 "aggregate": requirement.aggregate,
+                                 "optional": requirement.optional,
+                                 "filter": requirement.original_filter})
 
             # Provided services (list of list of specifications)
             svc = result["services"] = []
@@ -1137,19 +1089,19 @@ class _IPopoService(object):
 
             handlers_dict = result["handlers"] = {}
             for handler in handlers:
-                handlers_dict[handler] = copy.deepcopy(\
-                                                context.get_handler(handler))
+                handlers_dict[handler] = \
+                    copy.deepcopy(context.get_handler(handler))
 
             return result
 
 # ------------------------------------------------------------------------------
 
+
 @BundleActivator
 class _IPopoActivator(object):
     """
     The iPOPO bundle activator for Pelix
     """
-
     def __init__(self):
         """
         Sets up the activator
@@ -1158,7 +1110,6 @@ class _IPopoActivator(object):
         self._service = None
         self._bundles = []
 
-
     def start(self, context):
         """
         The bundle has started
@@ -1175,7 +1126,6 @@ class _IPopoActivator(object):
             except BundleException as ex:
                 _logger.error("Error installing handler %s: %s", handler, ex)
 
-
         # Register the iPOPO service
         self._service = _IPopoService(context)
         self._registration = context.register_service(constants.SERVICE_IPOPO,
@@ -1196,7 +1146,6 @@ class _IPopoActivator(object):
                 # Bundle is active, register its factories
                 self._service._register_bundle_factories(bundle)
 
-
     def stop(self, context):
         """
         The bundle has stopped
