@@ -6,7 +6,7 @@ Properties handler
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.5.6
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -27,7 +27,7 @@ Properties handler
 """
 
 # Module version
-__version_info__ = (0, 5, 6)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -44,6 +44,7 @@ import pelix.ipopo.handlers.constants as constants
 
 # ------------------------------------------------------------------------------
 
+
 class _HandlerFactory(constants.HandlerFactory):
     """
     Factory service for service registration handlers
@@ -71,7 +72,6 @@ class _Activator(object):
         """
         self._registration = None
 
-
     def start(self, context):
         """
         Bundle started
@@ -82,10 +82,8 @@ class _Activator(object):
 
         # Register the handler factory service
         self._registration = context.register_service(
-                                      constants.SERVICE_IPOPO_HANDLER_FACTORY,
-                                      _HandlerFactory(),
-                                      properties)
-
+            constants.SERVICE_IPOPO_HANDLER_FACTORY,
+            _HandlerFactory(), properties)
 
     def stop(self, context):
         """
@@ -97,6 +95,7 @@ class _Activator(object):
 
 # ------------------------------------------------------------------------------
 
+
 class PropertiesHandler(constants.Handler):
     """
     Handles the properties
@@ -107,7 +106,6 @@ class PropertiesHandler(constants.Handler):
         """
         self._ipopo_instance = None
 
-
     def _field_property_generator(self):
         """
         Generates the methods called by the injected class properties
@@ -125,7 +123,6 @@ class PropertiesHandler(constants.Handler):
             """
             return properties.get(name, None)
 
-
         def set_value(self, name, new_value):
             """
             Sets the property value and trigger an update event
@@ -146,8 +143,7 @@ class PropertiesHandler(constants.Handler):
 
             return new_value
 
-        return (get_value, set_value)
-
+        return get_value, set_value
 
     def manipulate(self, stored_instance, component_instance):
         """
