@@ -6,7 +6,7 @@ Dependency handler
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.5.6
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -27,7 +27,7 @@ Dependency handler
 """
 
 # Module version
-__version_info__ = (0, 5, 6)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -49,6 +49,7 @@ import threading
 
 # ------------------------------------------------------------------------------
 
+
 class _HandlerFactory(constants.HandlerFactory):
     """
     Factory service for service registration handlers
@@ -84,7 +85,6 @@ class _HandlerFactory(constants.HandlerFactory):
 
         return new_requirements
 
-
     def get_handlers(self, component_context, instance):
         """
         Sets up service providers for the given component
@@ -95,10 +95,9 @@ class _HandlerFactory(constants.HandlerFactory):
         """
         # Extract information from the context
         requirements = component_context.get_handler(
-                                         ipopo_constants.HANDLER_REQUIRES)
+            ipopo_constants.HANDLER_REQUIRES)
         requires_filters = component_context.properties.get(
-                                         ipopo_constants.IPOPO_REQUIRES_FILTERS,
-                                         None)
+            ipopo_constants.IPOPO_REQUIRES_FILTERS, None)
 
         # Prepare requirements
         requirements = self._prepare_requirements(requirements,
@@ -127,7 +126,6 @@ class _Activator(object):
         """
         self._registration = None
 
-
     def start(self, context):
         """
         Bundle started
@@ -138,10 +136,8 @@ class _Activator(object):
 
         # Register the handler factory service
         self._registration = context.register_service(
-                                      constants.SERVICE_IPOPO_HANDLER_FACTORY,
-                                      _HandlerFactory(),
-                                      properties)
-
+            constants.SERVICE_IPOPO_HANDLER_FACTORY,
+            _HandlerFactory(), properties)
 
     def stop(self, context):
         """
@@ -153,6 +149,7 @@ class _Activator(object):
 
 # ------------------------------------------------------------------------------
 
+
 class _RuntimeDependency(constants.DependencyHandler):
     """
     Manages a required dependency field when a component is running
@@ -182,7 +179,6 @@ class _RuntimeDependency(constants.DependencyHandler):
         # Current field value
         self._value = None
 
-
     def manipulate(self, stored_instance, component_instance):
         """
         Stores the given StoredInstance bean.
@@ -196,7 +192,6 @@ class _RuntimeDependency(constants.DependencyHandler):
         # ... and the bundle context
         self._context = stored_instance.bundle_context
 
-
     def clear(self):
         """
         Cleans up the manager. The manager can't be used after this method has
@@ -209,7 +204,6 @@ class _RuntimeDependency(constants.DependencyHandler):
         self._value = None
         self._field = None
 
-
     def get_bindings(self):
         """
         Retrieves the list of the references to the bound services
@@ -218,22 +212,19 @@ class _RuntimeDependency(constants.DependencyHandler):
         """
         raise NotImplementedError
 
-
     def get_field(self):
         """
         Returns the name of the field handled by this handler
         """
         return self._field
 
-
     def get_kinds(self):
         """
         Retrieves the kinds of this handler: 'dependency'
 
         :return: the kinds of this handler
         """
-        return (constants.KIND_DEPENDENCY,)
-
+        return constants.KIND_DEPENDENCY,
 
     def get_value(self):
         """
@@ -244,7 +235,6 @@ class _RuntimeDependency(constants.DependencyHandler):
         """
         return self._value
 
-
     def is_valid(self):
         """
         Tests if the dependency is in a valid state
@@ -252,7 +242,6 @@ class _RuntimeDependency(constants.DependencyHandler):
         return (self.requirement is not None and self.requirement.optional) \
             or self._value is not None
 
-
     def on_service_arrival(self, svc_ref):
         """
         Called when a service has been registered in the framework
@@ -261,7 +250,6 @@ class _RuntimeDependency(constants.DependencyHandler):
         """
         raise NotImplementedError
 
-
     def on_service_departure(self, svc_ref):
         """
         Called when a service has been registered in the framework
@@ -270,7 +258,6 @@ class _RuntimeDependency(constants.DependencyHandler):
         """
         raise NotImplementedError
 
-
     def on_service_modify(self, svc_ref, old_properties):
         """
         Called when a service has been registered in the framework
@@ -280,13 +267,12 @@ class _RuntimeDependency(constants.DependencyHandler):
         """
         raise NotImplementedError
 
-
     def service_changed(self, event):
         """
         Called by the framework when a service event occurs
         """
         if self._ipopo_instance is None \
-        or not self._ipopo_instance.check_event(event):
+                or not self._ipopo_instance.check_event(event):
             # stop() and clean() may have been called after we have been put
             # inside a listener list copy...
             # or we've been told to ignore this event
@@ -309,7 +295,6 @@ class _RuntimeDependency(constants.DependencyHandler):
             # Modified properties (can be a new injection)
             self.on_service_modify(svc_ref, event.get_previous_properties())
 
-
     def start(self):
         """
         Starts the dependency manager
@@ -318,7 +303,6 @@ class _RuntimeDependency(constants.DependencyHandler):
                                            self.requirement.filter,
                                            self.requirement.specification)
 
-
     def stop(self):
         """
         Stops the dependency manager (must be called before clear())
@@ -341,7 +325,6 @@ class SimpleDependency(_RuntimeDependency):
         # We have only one reference to keep
         self.reference = None
 
-
     def clear(self):
         """
         Cleans up the manager. The manager can't be used after this method has
@@ -350,7 +333,6 @@ class SimpleDependency(_RuntimeDependency):
         self.reference = None
         super(SimpleDependency, self).clear()
 
-
     def get_bindings(self):
         """
         Retrieves the list of the references to the bound services
@@ -360,11 +342,9 @@ class SimpleDependency(_RuntimeDependency):
         with self._lock:
             if self.reference:
                 return [self.reference]
-
             else:
                 return []
 
-
     def on_service_arrival(self, svc_ref):
         """
         Called when a service has been registered in the framework
@@ -380,7 +360,6 @@ class SimpleDependency(_RuntimeDependency):
                 self._ipopo_instance.bind(self, self._value, self.reference)
                 return True
 
-
     def on_service_departure(self, svc_ref):
         """
         Called when a service has been unregistered from the framework
@@ -398,7 +377,6 @@ class SimpleDependency(_RuntimeDependency):
                 self._ipopo_instance.unbind(self, service, svc_ref)
                 return True
 
-
     def on_service_modify(self, svc_ref, old_properties):
         """
         Called when a service has been modified in the framework
@@ -416,7 +394,6 @@ class SimpleDependency(_RuntimeDependency):
                 self._ipopo_instance.update(self, self._value, svc_ref,
                                             old_properties)
 
-
     def stop(self):
         """
         Stops the dependency manager (must be called before clear())
@@ -428,7 +405,6 @@ class SimpleDependency(_RuntimeDependency):
             # Return a list
             return [(self._value, self.reference)]
 
-
     def try_binding(self):
         """
         Searches for the required service if needed
@@ -442,8 +418,8 @@ class SimpleDependency(_RuntimeDependency):
 
             # Get all matching services
             ref = self._context \
-                        .get_service_reference(self.requirement.specification,
-                                               self.requirement.filter)
+                .get_service_reference(self.requirement.specification,
+                                       self.requirement.filter)
             if ref is not None:
                 # Found a service
                 self.on_service_arrival(ref)
@@ -465,7 +441,6 @@ class AggregateDependency(_RuntimeDependency):
         # Future injected value
         self._future_value = None
 
-
     def clear(self):
         """
         Cleans up the manager. The manager can't be used after this method has
@@ -480,7 +455,6 @@ class AggregateDependency(_RuntimeDependency):
 
         super(AggregateDependency, self).clear()
 
-
     def get_bindings(self):
         """
         Retrieves the list of the references to the bound services
@@ -490,7 +464,6 @@ class AggregateDependency(_RuntimeDependency):
         with self._lock:
             return list(self.services.keys())
 
-
     def get_value(self):
         """
         Retrieves the value to inject in the component
@@ -504,7 +477,6 @@ class AggregateDependency(_RuntimeDependency):
             else:
                 return None
 
-
     def is_valid(self):
         """
         Tests if the dependency is in a valid state
@@ -512,7 +484,6 @@ class AggregateDependency(_RuntimeDependency):
         return (self.requirement is not None and self.requirement.optional) \
             or self._future_value is not None
 
-
     def on_service_arrival(self, svc_ref):
         """
         Called when a service has been registered in the framework
@@ -535,7 +506,6 @@ class AggregateDependency(_RuntimeDependency):
                 self._ipopo_instance.bind(self, service, svc_ref)
                 return True
 
-
     def on_service_departure(self, svc_ref):
         """
         Called when a service has been unregistered from the framework
@@ -560,7 +530,6 @@ class AggregateDependency(_RuntimeDependency):
                 self._ipopo_instance.unbind(self, service, svc_ref)
                 return True
 
-
     def on_service_modify(self, svc_ref, old_properties):
         """
         Called when a service has been modified in the framework
@@ -574,13 +543,11 @@ class AggregateDependency(_RuntimeDependency):
             if svc_ref not in self.services:
                 # A previously registered service now matches our filter
                 return self.on_service_arrival(svc_ref)
-
             else:
                 # Notify the property modification
                 self._ipopo_instance.update(self, self.services[svc_ref],
                                             svc_ref, old_properties)
 
-
     def stop(self):
         """
         Stops the dependency manager (must be called before clear())
@@ -590,14 +557,8 @@ class AggregateDependency(_RuntimeDependency):
         super(AggregateDependency, self).stop()
 
         if self.services:
-            results = [(service, reference)
-                       for reference, service in self.services.items()]
-
-        else:
-            results = None
-
-        return results
-
+            return [(service, reference)
+                    for reference, service in self.services.items()]
 
     def try_binding(self):
         """
@@ -613,8 +574,8 @@ class AggregateDependency(_RuntimeDependency):
 
             # Get all matching services
             refs = self._context \
-                    .get_all_service_references(self.requirement.specification,
-                                                self.requirement.filter)
+                .get_all_service_references(self.requirement.specification,
+                                            self.requirement.filter)
             if not refs:
                 # No match found
                 return
