@@ -6,7 +6,7 @@ RequiresMap handler implementation
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.5.6
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -27,7 +27,7 @@ RequiresMap handler implementation
 """
 
 # Module version
-__version_info__ = (0, 5, 6)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -49,6 +49,7 @@ import threading
 
 # ------------------------------------------------------------------------------
 
+
 class _HandlerFactory(constants.HandlerFactory):
     """
     Factory service for service registration handlers
@@ -87,7 +88,6 @@ class _HandlerFactory(constants.HandlerFactory):
 
         return new_requirements
 
-
     def get_handlers(self, component_context, instance):
         """
         Sets up service providers for the given component
@@ -98,10 +98,9 @@ class _HandlerFactory(constants.HandlerFactory):
         """
         # Extract information from the context
         configs = component_context.get_handler(
-                                         ipopo_constants.HANDLER_REQUIRES_MAP)
+            ipopo_constants.HANDLER_REQUIRES_MAP)
         requires_filters = component_context.properties.get(
-                                         ipopo_constants.IPOPO_REQUIRES_FILTERS,
-                                         None)
+            ipopo_constants.IPOPO_REQUIRES_FILTERS, None)
 
         # Prepare requirements
         configs = self._prepare_requirements(configs, requires_filters)
@@ -134,7 +133,6 @@ class _Activator(object):
         """
         self._registration = None
 
-
     def start(self, context):
         """
         Bundle started
@@ -145,10 +143,8 @@ class _Activator(object):
 
         # Register the handler factory service
         self._registration = context.register_service(
-                                      constants.SERVICE_IPOPO_HANDLER_FACTORY,
-                                      _HandlerFactory(),
-                                      properties)
-
+            constants.SERVICE_IPOPO_HANDLER_FACTORY,
+            _HandlerFactory(), properties)
 
     def stop(self, context):
         """
@@ -160,6 +156,7 @@ class _Activator(object):
 
 # ------------------------------------------------------------------------------
 
+
 class _RuntimeDependency(constants.DependencyHandler):
     """
     Manages a required dependency field when a component is running
@@ -200,7 +197,6 @@ class _RuntimeDependency(constants.DependencyHandler):
         # Future injected dictionary
         self._future_value = {}
 
-
     def manipulate(self, stored_instance, component_instance):
         """
         Stores the given StoredInstance bean.
@@ -217,7 +213,6 @@ class _RuntimeDependency(constants.DependencyHandler):
         # Set the default value for the field: an empty dictionary
         setattr(component_instance, self._field, {})
 
-
     def clear(self):
         """
         Cleans up the manager. The manager can't be used after this method has
@@ -236,7 +231,6 @@ class _RuntimeDependency(constants.DependencyHandler):
         self._future_value = None
         self._field = None
 
-
     def get_bindings(self):
         """
         Retrieves the list of the references to the bound services
@@ -246,22 +240,19 @@ class _RuntimeDependency(constants.DependencyHandler):
         with self._lock:
             return list(self.services.keys())
 
-
     def get_field(self):
         """
         Returns the name of the field handled by this handler
         """
         return self._field
 
-
     def get_kinds(self):
         """
         Retrieves the kinds of this handler: 'dependency'
 
         :return: the kinds of this handler
         """
-        return (constants.KIND_DEPENDENCY,)
-
+        return constants.KIND_DEPENDENCY,
 
     def get_value(self):
         """
@@ -273,7 +264,6 @@ class _RuntimeDependency(constants.DependencyHandler):
         with self._lock:
             return self._future_value.copy()
 
-
     def is_valid(self):
         """
         Tests if the dependency is in a valid state
@@ -281,7 +271,6 @@ class _RuntimeDependency(constants.DependencyHandler):
         return (self.requirement is not None and self.requirement.optional) \
             or bool(self._future_value)
 
-
     def on_service_arrival(self, svc_ref):
         """
         Called when a service has been registered in the framework
@@ -290,7 +279,6 @@ class _RuntimeDependency(constants.DependencyHandler):
         """
         raise NotImplementedError
 
-
     def on_service_departure(self, svc_ref):
         """
         Called when a service has been registered in the framework
@@ -299,7 +287,6 @@ class _RuntimeDependency(constants.DependencyHandler):
         """
         raise NotImplementedError
 
-
     def on_service_modify(self, svc_ref, old_properties):
         """
         Called when a service has been registered in the framework
@@ -309,13 +296,12 @@ class _RuntimeDependency(constants.DependencyHandler):
         """
         raise NotImplementedError
 
-
     def service_changed(self, event):
         """
         Called by the framework when a service event occurs
         """
         if self._ipopo_instance is None \
-        or not self._ipopo_instance.check_event(event):
+                or not self._ipopo_instance.check_event(event):
             # stop() and clean() may have been called after we have been put
             # inside a listener list copy...
             # or we've been told to ignore this event
@@ -338,7 +324,6 @@ class _RuntimeDependency(constants.DependencyHandler):
             # Modified properties (can be a new injection)
             self.on_service_modify(svc_ref, event.get_previous_properties())
 
-
     def start(self):
         """
         Starts the dependency manager
@@ -347,7 +332,6 @@ class _RuntimeDependency(constants.DependencyHandler):
                                            self.requirement.filter,
                                            self.requirement.specification)
 
-
     def stop(self):
         """
         Stops the dependency manager (must be called before clear())
@@ -357,13 +341,8 @@ class _RuntimeDependency(constants.DependencyHandler):
         self._context.remove_service_listener(self)
 
         if self.services:
-            results = [(service, reference)
-                       for reference, service in self.services.items()]
-        else:
-            results = None
-
-        return results
-
+            return [(service, reference)
+                    for reference, service in self.services.items()]
 
     def try_binding(self):
         """
@@ -379,8 +358,8 @@ class _RuntimeDependency(constants.DependencyHandler):
 
             # Get all matching services
             refs = self._context \
-                    .get_all_service_references(self.requirement.specification,
-                                                self.requirement.filter)
+                .get_all_service_references(self.requirement.specification,
+                                            self.requirement.filter)
             if not refs:
                 # No match found
                 return
@@ -426,7 +405,7 @@ class SimpleDependency(_RuntimeDependency):
                 # Get the key property
                 prop_value = svc_ref.get_property(self._key)
                 if prop_value not in self._future_value \
-                and prop_value is not None or self._allow_none:
+                        and prop_value is not None or self._allow_none:
                     # Matching new property value
                     service = self._context.get_service(svc_ref)
 
@@ -438,7 +417,6 @@ class SimpleDependency(_RuntimeDependency):
                     self._ipopo_instance.bind(self, service, svc_ref)
                     return True
 
-
     def on_service_departure(self, svc_ref):
         """
         Called when a service has been unregistered from the framework
@@ -459,7 +437,6 @@ class SimpleDependency(_RuntimeDependency):
                 self._ipopo_instance.unbind(self, service, svc_ref)
                 return True
 
-
     def on_service_modify(self, svc_ref, old_properties):
         """
         Called when a service has been modified in the framework
@@ -480,7 +457,7 @@ class SimpleDependency(_RuntimeDependency):
 
                 if old_value != prop_value:
                     if prop_value is not None or self._allow_none \
-                    and prop_value not in self._future_value:
+                            and prop_value not in self._future_value:
                         # New property accepted and not yet in use
                         del self._future_value[old_value]
                         self._future_value[prop_value] = service
@@ -503,7 +480,8 @@ class SimpleDependency(_RuntimeDependency):
 
 class AggregateDependency(_RuntimeDependency):
     """
-    Manages an aggregated dependency field: multiple services per dictionary key
+    Manages an aggregated dependency field: multiple services per dictionary
+    key
     """
     def __store_service(self, key, service):
         """
@@ -514,7 +492,6 @@ class AggregateDependency(_RuntimeDependency):
         """
         self._future_value.setdefault(key, []).append(service)
 
-
     def __remove_service(self, key, service):
         """
         Removes the given service from the future dictionary
@@ -536,7 +513,6 @@ class AggregateDependency(_RuntimeDependency):
             # if allow_none is False
             pass
 
-
     def get_value(self):
         """
         Retrieves the value to inject in the component
@@ -548,11 +524,9 @@ class AggregateDependency(_RuntimeDependency):
             if self._future_value is not None:
                 return dict((key, value[:])
                             for key, value in self._future_value.items())
-
             else:
                 return None
 
-
     def on_service_arrival(self, svc_ref):
         """
         Called when a service has been registered in the framework
@@ -576,7 +550,6 @@ class AggregateDependency(_RuntimeDependency):
                     self._ipopo_instance.bind(self, service, svc_ref)
                     return True
 
-
     def on_service_departure(self, svc_ref):
         """
         Called when a service has been unregistered from the framework
@@ -599,7 +572,6 @@ class AggregateDependency(_RuntimeDependency):
                 self._ipopo_instance.unbind(self, service, svc_ref)
                 return True
 
-
     def on_service_modify(self, svc_ref, old_properties):
         """
         Called when a service has been modified in the framework
