@@ -6,7 +6,7 @@ Pelix remote services package
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.5.6
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -27,16 +27,18 @@ Pelix remote services package
 """
 
 # Module version
-__version_info__ = (0, 5, 6)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
 __docformat__ = "restructuredtext en"
 
-#-------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 FACTORY_REGISTRY_SERVLET = "pelix-remote-dispatcher-servlet-factory"
-""" Name of the factory of the Servlet component giving access to registries """
+"""
+Name of the factory of the Servlet component giving access to registries
+"""
 
 
 FACTORY_DISCOVERY_MQTT = "pelix-remote-discovery-mqtt-factory"
@@ -69,7 +71,7 @@ FACTORY_TRANSPORT_MQTTRPC_EXPORTER = "pelix-mqttrpc-exporter-factory"
 FACTORY_TRANSPORT_MQTTRPC_IMPORTER = "pelix-mqttrpc-importer-factory"
 """ Name of the MQTT-RPC importer component factory """
 
-#-------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 SERVICE_DISPATCHER = "pelix.remote.dispatcher"
 """ Remote call dispatcher """
@@ -92,7 +94,7 @@ SERVICE_EXPORT_ENDPOINT_LISTENER = "pelix.remote.endpoint.export.listener"
 SERVICE_IMPORT_ENDPOINT_LISTENER = "pelix.remote.endpoint.import.listener"
 """ Imported endpoints listener specification """
 
-#-------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 # Properties used by Pelix
 
 PROP_ENDPOINT_NAME = "endpoint.name"
@@ -104,10 +106,20 @@ PREFIX_PROP_EXPORTED = "service.exported."
 PROP_IMPORTED_INTERFACES = "service.imported.interfaces"
 """ Imported specifications (mirror of PROP_EXPORTED_INTERFACES) """
 
-#-------------------------------------------------------------------------------
-# Properties declared in RSA specifications
+PROP_SYNONYMS = "pelix.remote.synonyms"
+"""
+Synonyms of the exported specifications. Used of multi-language applications.
+"""
 
-# Already known
+PROP_EXPORT_REJECT = "pelix.remote.export.reject"
+"""
+List of specifications that must never exported. Acts as a filter when
+exporting all other specifications with the "service.exported.interfaces"
+property set to "*"
+"""
+
+# ------------------------------------------------------------------------------
+# Properties declared in RSA specifications
 
 PROP_EXPORTED_CONFIGS = "service.exported.configs"
 """ Export configurations (xmlrpc, ...) (str or array of str) """
@@ -121,8 +133,6 @@ PROP_IMPORTED = "service.imported"
 PROP_IMPORTED_CONFIGS = "service.imported.configs"
 """ Configurations of the imported service (array of str) """
 
-# New ones
-
 PROP_EXPORTED_INTENTS = "service.exported.intents"
 """
 Service property identifying the intents that the distribution provider must
@@ -174,8 +184,8 @@ endpoint is not for an OSGi service. (int)
 
 PROP_REMOTE_CONFIGS_SUPPORTED = "remote.configs.supported"
 """
-Service property identifying the configuration types supported by a distribution
-provider.
+Service property identifying the configuration types supported by a
+distribution provider.
 Registered by the distribution provider on one of its services to indicate the
 supported configuration types. (str or array of str)
 """
@@ -187,7 +197,7 @@ Registered by the distribution provider on one of its services to indicate the
 vocabulary of implemented intents. (str or array of str)
 """
 
-#-------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 # Zeroconf discovery properties
 
 PROP_ZEROCONF_TYPE = "zeroconf.service.type"
@@ -200,7 +210,8 @@ WARNING: Doesn't work as is with pyzeroconf: the library must be patched.
 => checking in zeroconf.mdns.DNSQuestion must be removed (around line 220)
 """
 
-#-------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
+
 
 class RemoteServiceError(Exception):
     """
