@@ -6,7 +6,7 @@ Pelix remote services: Specifications handling utility methods
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.3.0
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -27,7 +27,7 @@ Pelix remote services: Specifications handling utility methods
 """
 
 # Module version
-__version_info__ = (0, 2, 0)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -40,14 +40,16 @@ from pelix.utilities import is_string
 import pelix.constants
 import pelix.ldapfilter
 import pelix.remote
+import pelix.utilities
 
 # Standard library
 try:
     # Python 3
+    # pylint: disable=F0401,E0611
     from urllib.parse import urlparse
-
 except ImportError:
     # Python 2
+    # pylint: disable=F0401
     from urlparse import urlparse
 
 # ------------------------------------------------------------------------------
@@ -55,7 +57,8 @@ except ImportError:
 PYTHON_LANGUAGE = "python"
 """ Prefix to use for the Python specifications """
 
-#-------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
+
 
 class ExportEndpoint(object):
     """
@@ -102,14 +105,12 @@ class ExportEndpoint(object):
         # Exported specifications
         self.__exported_specs = []
         exported_specs = compute_exported_specifications(svc_ref)
-        if not exported_specs:
-            raise ValueError("Endpoint {0}, {1}, exports nothing" \
-                             .format(self.__uid, self.__name))
-
-        else:
+        if exported_specs:
             # Transform the specifications for export (add the language prefix)
             self.__exported_specs = format_specifications(exported_specs)
-
+        else:
+            raise ValueError("Endpoint {0}, {1}, exports nothing"
+                             .format(self.__uid, self.__name))
 
     def __hash__(self):
         """
@@ -117,21 +118,18 @@ class ExportEndpoint(object):
         """
         return hash(self.__uid)
 
-
     def __eq__(self, other):
         """
         Equality checked by UID
         """
         return self.__uid == other.uid
 
-
     def __ne__(self, other):
         """
         Inequality checked by UID
         """
         return self.__uid != other.uid
 
-
     def __str__(self):
         """
         String representation
@@ -140,7 +138,6 @@ class ExportEndpoint(object):
             .format(self.__uid, self.__configurations,
                     self.__exported_specs)
 
-
     def get_properties(self):
         """
         Returns merged properties
@@ -162,7 +159,6 @@ class ExportEndpoint(object):
 
         return properties
 
-
     def make_import_properties(self):
         """
         Returns the properties of this endpoint where export properties have
@@ -177,7 +173,6 @@ class ExportEndpoint(object):
         props[pelix.remote.PROP_ENDPOINT_FRAMEWORK_UUID] = self.__fw_uid
         return props
 
-
     def rename(self, new_name):
         """
         Updates the endpoint name
@@ -188,7 +183,6 @@ class ExportEndpoint(object):
             # Update the name only if the new one is valid
             self.__name = new_name
 
-
     # Access to the service
     @property
     def instance(self):
@@ -197,7 +191,6 @@ class ExportEndpoint(object):
         """
         return self.__instance
 
-
     @property
     def reference(self):
         """
@@ -205,7 +198,6 @@ class ExportEndpoint(object):
         """
         return self.__reference
 
-
     # End point properties
     @property
     def uid(self):
@@ -214,7 +206,6 @@ class ExportEndpoint(object):
         """
         return self.__uid
 
-
     @property
     def framework(self):
         """
@@ -222,7 +213,6 @@ class ExportEndpoint(object):
         """
         return self.__fw_uid
 
-
     @property
     def configurations(self):
         """
@@ -244,7 +234,8 @@ class ExportEndpoint(object):
         """
         return self.__exported_specs
 
-#-------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
+
 
 class ImportEndpoint(object):
     """
@@ -275,13 +266,13 @@ class ImportEndpoint(object):
             self.__configurations = tuple(configurations)
 
         # Extract the language prefix in specifications
-        self.__specifications = extract_specifications(specifications)
+        self.__specifications = extract_specifications(specifications,
+                                                       self.__properties)
 
         # Public variable: the source server,
         # set up by a Pelix discovery service
         self.server = None
 
-
     def __str__(self):
         """
         String representation of the end point
@@ -290,7 +281,6 @@ class ImportEndpoint(object):
             "specs={3})".format(self.__uid, self.__fw_uid,
                                 self.__configurations, self.__specifications)
 
-
     # Access to the service informations
     @property
     def specifications(self):
@@ -299,7 +289,6 @@ class ImportEndpoint(object):
         """
         return self.__specifications
 
-
     @property
     def properties(self):
         """
@@ -307,7 +296,6 @@ class ImportEndpoint(object):
         """
         return self.__properties
 
-
     @properties.setter
     def properties(self, properties):
         """
@@ -316,7 +304,6 @@ class ImportEndpoint(object):
         # Keep a copy of the new properties
         self.__properties = properties.copy() if properties else {}
 
-
     # End point properties
     @property
     def uid(self):
@@ -348,10 +335,13 @@ class ImportEndpoint(object):
 
 # ------------------------------------------------------------------------------
 
+
 class EndpointDescription(object):
     """
     Endpoint description bean, according to OSGi specifications:
-    http://www.osgi.org/javadoc/r4v42/org/osgi/service/remoteserviceadmin/EndpointDescription.html
+
+    http://www.osgi.org/javadoc/r4v42/org/osgi/service/remoteserviceadmin/
+    EndpointDescription.html
 
     This is an importer-side description
     """
@@ -373,9 +363,7 @@ class EndpointDescription(object):
         if svc_ref is not None:
             # Service ID
             all_properties[pelix.remote.PROP_ENDPOINT_SERVICE_ID] = \
-                                svc_ref.get_property(pelix.constants.SERVICE_ID)
-
-            # TODO: Framework UUID ??
+                svc_ref.get_property(pelix.constants.SERVICE_ID)
 
         # Convert properties
         self.__properties = to_import_properties(all_properties)
@@ -386,28 +374,24 @@ class EndpointDescription(object):
         # Keep a copy of the endpoint ID
         self.__endpoint_id = self.get_id()
 
-
     def __hash__(self):
         """
         Custom hash, as we override equality tests
         """
         return hash(self.__endpoint_id)
 
-
     def __eq__(self, other):
         """
         Equality checked by UID
         """
         return self.__endpoint_id == other.__endpoint_id
 
-
     def __ne__(self, other):
         """
         Inequality checked by UID
         """
         return self.__endpoint_id != other.__endpoint_id
 
-
     def __str__(self):
         """
         String representation
@@ -417,7 +401,6 @@ class EndpointDescription(object):
                                             self.get_service_id(),
                                             self.get_framework_uuid())
 
-
     def __check_properties(self, props):
         """
         Checks that the given dictionary doesn't have export keys and has
@@ -442,7 +425,6 @@ class EndpointDescription(object):
             if key in props:
                 raise ValueError("Export property found: {0}".format(key))
 
-
     def get_configuration_types(self):
         """
         Returns the configuration types.
@@ -452,9 +434,10 @@ class EndpointDescription(object):
         configuration parameters.
         There are many different types but each endpoint is configured by only
         one configuration type.
-        However, a distribution provider can be aware of different configuration
-        types and provide synonyms to increase the change a receiving
-        distribution provider can create a connection to this endpoint.
+        However, a distribution provider can be aware of different
+        configuration types and provide synonyms to increase the change a
+        receiving distribution provider can create a connection to this
+        endpoint.
         This value of the configuration types is stored in the
         pelix.remote.PROP_IMPORTED_CONFIGS service property.
 
@@ -463,7 +446,6 @@ class EndpointDescription(object):
         # Return a copy of the list
         return self.__properties[pelix.remote.PROP_IMPORTED_CONFIGS][:]
 
-
     def get_framework_uuid(self):
         """
         Returns the UUID of the framework exporting this endpoint, or None
@@ -472,14 +454,12 @@ class EndpointDescription(object):
         """
         return self.__properties.get(pelix.remote.PROP_ENDPOINT_FRAMEWORK_UUID)
 
-
     def get_id(self):
         """
         Returns the endpoint's id.
         """
         return self.__properties[pelix.remote.PROP_ENDPOINT_ID]
 
-
     def get_intents(self):
         """
         Returns the list of intents implemented by this endpoint.
@@ -499,7 +479,6 @@ class EndpointDescription(object):
         except KeyError:
             return []
 
-
     def get_interfaces(self):
         """
         Provides the list of interfaces implemented by the exported service.
@@ -508,7 +487,6 @@ class EndpointDescription(object):
         """
         return self.__properties[pelix.constants.OBJECTCLASS][:]
 
-
     def get_package_version(self, package):
         """
         Provides the version of the given package name.
@@ -527,8 +505,7 @@ class EndpointDescription(object):
 
         except KeyError:
             # No version
-            return (0, 0, 0)
-
+            return 0, 0, 0
 
     def get_properties(self):
         """
@@ -538,7 +515,6 @@ class EndpointDescription(object):
         """
         return self.__properties.copy()
 
-
     def get_service_id(self):
         """
         Returns the service id for the service exported through this endpoint.
@@ -551,7 +527,6 @@ class EndpointDescription(object):
             # Not found
             return 0
 
-
     def is_same_service(self, endpoint):
         """
         Tests if this endpoint and the given one have the same framework UUID
@@ -563,7 +538,6 @@ class EndpointDescription(object):
         return self.get_framework_uuid() == endpoint.get_framework_uuid() \
             and self.get_service_id() == endpoint.get_service_id()
 
-
     def matches(self, ldap_filter):
         """
         Tests the properties of this EndpointDescription against the given
@@ -572,9 +546,8 @@ class EndpointDescription(object):
         :param ldap_filter: A filter
         :return: True if properties matches the filter
         """
-        return pelix.ldapfilter.get_ldap_filter(ldap_filter)\
-                                                    .matches(self.__properties)
-
+        return pelix.ldapfilter.get_ldap_filter(ldap_filter) \
+            .matches(self.__properties)
 
     def to_import(self):
         """
@@ -605,7 +578,6 @@ class EndpointDescription(object):
         return ImportEndpoint(self.get_id(), fw_uid, configurations, name,
                               specifications, properties)
 
-
     @classmethod
     def from_export(cls, endpoint):
         """
@@ -621,9 +593,10 @@ class EndpointDescription(object):
 
         # Set import keys
         properties[pelix.remote.PROP_ENDPOINT_ID] = endpoint.uid
-        properties[pelix.remote.PROP_IMPORTED_CONFIGS] = endpoint.configurations
+        properties[pelix.remote.PROP_IMPORTED_CONFIGS] = \
+            endpoint.configurations
         properties[pelix.remote.PROP_EXPORTED_INTERFACES] = \
-                                                         endpoint.specifications
+            endpoint.specifications
 
         # Remove export keys
         for key in (pelix.remote.PROP_EXPORTED_CONFIGS,
@@ -638,12 +611,13 @@ class EndpointDescription(object):
         # Other information
         properties[pelix.remote.PROP_ENDPOINT_NAME] = endpoint.name
         properties[pelix.remote.PROP_ENDPOINT_FRAMEWORK_UUID] = \
-                                                            endpoint.framework
+            endpoint.framework
 
         return EndpointDescription(None, properties)
 
 # ------------------------------------------------------------------------------
 
+
 def to_import_properties(properties):
     """
     Returns a dictionary where export properties have been replaced by import
@@ -661,7 +635,7 @@ def to_import_properties(properties):
     # Remote service ID
     try:
         props[pelix.remote.PROP_ENDPOINT_SERVICE_ID] = \
-                                        props.pop(pelix.constants.SERVICE_ID)
+            props.pop(pelix.constants.SERVICE_ID)
     except KeyError:
         # No service ID
         pass
@@ -685,6 +659,7 @@ def to_import_properties(properties):
 
 # ------------------------------------------------------------------------------
 
+
 def compute_exported_specifications(svc_ref):
     """
     Computes the list of specifications exported by the given service
@@ -692,41 +667,55 @@ def compute_exported_specifications(svc_ref):
     :param svc_ref: A ServiceReference
     :return: The list of exported specifications (or an empty list)
     """
-    specs = svc_ref.get_property(pelix.framework.OBJECTCLASS)
-    exported_specs = svc_ref.get_property(pelix.remote.PROP_EXPORTED_INTERFACES)
+    specs = svc_ref.get_property(pelix.constants.OBJECTCLASS)
+    exported_specs = svc_ref.get_property(
+        pelix.remote.PROP_EXPORTED_INTERFACES)
+    rejected_specs = pelix.utilities.to_iterable(
+        svc_ref.get_property(pelix.remote.PROP_EXPORT_REJECT), False)
 
     if exported_specs and exported_specs != "*":
         # A set of specifications is exported, replace "objectClass"
-        if isinstance(exported_specs, (list, tuple, set, frozenset)):
-            return [spec for spec in specs if spec in exported_specs]
-
+        iterable_exports = pelix.utilities.to_iterable(exported_specs, False)
+        all_exported_specs = [spec for spec in specs
+                              if spec in iterable_exports]
     else:
         # Export everything
-        return specs
+        all_exported_specs = pelix.utilities.to_iterable(specs)
+
+    # Filter specifications
+    return [spec for spec in all_exported_specs if spec not in rejected_specs]
 
 
-def extract_specifications(specifications):
+def extract_specifications(specifications, properties):
     """
     Converts "python:/name" specifications to "name". Keeps the other
     specifications as is.
 
     :param specifications: The specifications found in a remote registration
-    :return: The filtered specifications (as a set)
+    :param properties: Service properties
+    :return: The filtered specifications (as a list)
     """
-    filtered_specs = set()
+    all_specs = set(pelix.utilities.to_iterable(specifications))
+    try:
+        synonyms = \
+            pelix.utilities.to_iterable(properties[pelix.remote.PROP_SYNONYMS],
+                                        False)
+        all_specs.update(synonyms)
+    except KeyError:
+        # No synonyms property
+        pass
 
-    for original in specifications:
+    filtered_specs = set()
+    for original in all_specs:
         try:
-            # Extract informations
+            # Extract information
             lang, spec = _extract_specification_parts(original)
             if lang == PYTHON_LANGUAGE:
                 # Language match: keep the name only
                 filtered_specs.add(spec)
-
             else:
                 # Keep the name as is
                 filtered_specs.add(original)
-
         except ValueError:
             # Ignore invalid specifications
             pass
@@ -771,7 +760,8 @@ def _extract_specification_parts(specification):
 
     except:
         # Invalid URL
-        raise ValueError("Invalid specification URL: {0}".format(specification))
+        raise ValueError("Invalid specification URL: {0}"
+                         .format(specification))
 
     # Extract the interface name
     interface = parsed.path
@@ -786,7 +776,7 @@ def _extract_specification_parts(specification):
         # Formatted name: un-escape it, without the starting '/'
         interface = _unescape_specification(interface[1:])
 
-    return (language, interface)
+    return language, interface
 
 
 def _format_specification(language, specification):
