@@ -14,7 +14,7 @@ when using remote services on the local host only.
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.3.0
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -35,7 +35,7 @@ when using remote services on the local host only.
 """
 
 # Module version
-__version_info__ = (0, 3, 0)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -44,6 +44,8 @@ __docformat__ = "restructuredtext en"
 # ------------------------------------------------------------------------------
 
 # Pelix utilities
+import pelix.constants
+from pelix.ipv6utils import ipproto_ipv6
 from pelix.utilities import to_bytes, to_str
 
 # Remote services
@@ -132,6 +134,7 @@ else:
 
 # ------------------------------------------------------------------------------
 
+
 def make_mreq(family, address):
     """
     Makes a mreq structure object for the given address and socket family.
@@ -169,6 +172,7 @@ def make_mreq(family, address):
 
 # ------------------------------------------------------------------------------
 
+
 def create_multicast_socket(address, port):
     """
     Creates a multicast socket according to the given address and port.
@@ -182,9 +186,9 @@ def create_multicast_socket(address, port):
     # Get the information about a datagram (UDP) socket, of any family
     try:
         addrs_info = socket.getaddrinfo(address, port, socket.AF_UNSPEC,
-                                       socket.SOCK_DGRAM)
+                                        socket.SOCK_DGRAM)
     except socket.gaierror:
-        raise ValueError("Error retrieving address informations ({0}, {1})" \
+        raise ValueError("Error retrieving address informations ({0}, {1})"
                          .format(address, port))
 
     if len(addrs_info) > 1:
@@ -229,14 +233,14 @@ def create_multicast_socket(address, port):
         # Allow multicast packets to get back on this host
         sock.setsockopt(socket.IPPROTO_IP, socket.IP_MULTICAST_LOOP, 1)
 
-    else:
+    elif sock.family == socket.AF_INET6:
         # IPv6
-        sock.setsockopt(socket.IPPROTO_IPV6, socket.IPV6_JOIN_GROUP, mreq)
+        sock.setsockopt(ipproto_ipv6(), socket.IPV6_JOIN_GROUP, mreq)
 
         # Allow multicast packets to get back on this host
-        sock.setsockopt(socket.IPPROTO_IPV6, socket.IPV6_MULTICAST_LOOP, 1)
+        sock.setsockopt(ipproto_ipv6(), socket.IPV6_MULTICAST_LOOP, 1)
 
-    return (sock, addr_info[4][0])
+    return sock, addr_info[4][0]
 
 
 def close_multicast_socket(sock, address):
@@ -263,13 +267,14 @@ def close_multicast_socket(sock, address):
 
         elif sock.family == socket.AF_INET6:
             # IPv6
-            sock.setsockopt(socket.IPPROTO_IPV6, socket.IPV6_LEAVE_GROUP, mreq)
+            sock.setsockopt(ipproto_ipv6(), socket.IPV6_LEAVE_GROUP, mreq)
 
     # Close the socket
     sock.close()
 
 # ------------------------------------------------------------------------------
 
+
 @ComponentFactory(pelix.remote.FACTORY_DISCOVERY_MULTICAST)
 @Provides(pelix.remote.SERVICE_EXPORT_ENDPOINT_LISTENER)
 @Requires('_access', pelix.remote.SERVICE_DISPATCHER_SERVLET)
@@ -303,7 +308,6 @@ class MulticastDiscovery(object):
         self._stop_event = threading.Event()
         self._thread = None
 
-
     def __make_basic_dict(self, event):
         """
         Prepares basic common information contained into an event packet
@@ -316,12 +320,10 @@ class MulticastDiscovery(object):
         access = self._access.get_access()
 
         # Make the event packet content
-        return {"sender": self._fw_uid,  # Framework UID
+        return {"sender": self._fw_uid,
                 "event": event,  # Kind of event
                 "access": {"port": access[0],  # Access to the dispatcher
-                           "path": access[1]}  # servlet
-                }
-
+                           "path": access[1]}}  # servlet
 
     def _make_endpoint_dict(self, event, endpoint):
         """
@@ -342,7 +344,6 @@ class MulticastDiscovery(object):
 
         return packet
 
-
     def _make_endpoints_dict(self, event, endpoints):
         """
         Prepares an event packet containing multiple endpoints
@@ -359,7 +360,6 @@ class MulticastDiscovery(object):
 
         return packet
 
-
     def __send_packet(self, data, target=None):
         """
         Sends a UDP datagram to the given target, if given, or to the multicast
@@ -378,7 +378,6 @@ class MulticastDiscovery(object):
         # Send the data
         self._socket.sendto(data, 0, target)
 
-
     def _send_discovery(self):
         """
         Sends a discovery packet, requesting others to indicate their services
@@ -387,7 +386,6 @@ class MulticastDiscovery(object):
         data = json.dumps(self.__make_basic_dict("discovery"))
         self.__send_packet(data)
 
-
     def endpoints_added(self, endpoints):
         """
         Multiple endpoints have been created
@@ -396,7 +394,6 @@ class MulticastDiscovery(object):
         data = json.dumps(self._make_endpoints_dict("add", endpoints))
         self.__send_packet(data)
 
-
     def endpoint_updated(self, endpoint, old_properties):
         """
         An end point is updated
@@ -405,7 +402,6 @@ class MulticastDiscovery(object):
         data = json.dumps(self._make_endpoint_dict("update", endpoint))
         self.__send_packet(data)
 
-
     def endpoint_removed(self, endpoint):
         """
         An end point is removed
@@ -414,7 +410,6 @@ class MulticastDiscovery(object):
         data = json.dumps(self._make_endpoint_dict("remove", endpoint))
         self.__send_packet(data)
 
-
     def _handle_packet(self, sender, raw_data):
         """
         Calls the method associated to the kind of event indicated in the given
@@ -446,7 +441,6 @@ class MulticastDiscovery(object):
         else:
             _logger.warning("Unknown event '%s' from %s", event, sender)
 
-
     def _handle_event_packet(self, sender, data):
         """
         Handles an end point event packet
@@ -480,7 +474,6 @@ class MulticastDiscovery(object):
             new_properties = data['new_properties']
             self._registry.update(endpoint_uid, new_properties)
 
-
     def _read_loop(self):
         """
         Reads packets from the socket
@@ -498,7 +491,6 @@ class MulticastDiscovery(object):
                 except Exception as ex:
                     _logger.exception("Error handling the packet: %s", ex)
 
-
     @Invalidate
     def invalidate(self, context):
         """
@@ -521,7 +513,6 @@ class MulticastDiscovery(object):
 
         _logger.debug("Multicast discovery invalidated")
 
-
     @Validate
     def validate(self, context):
         """
@@ -531,10 +522,11 @@ class MulticastDiscovery(object):
         self._port = int(self._port)
 
         # Get the framework UID
-        self._fw_uid = context.get_property(pelix.framework.FRAMEWORK_UID)
+        self._fw_uid = context.get_property(pelix.constants.FRAMEWORK_UID)
 
         # Create the socket
-        self._socket, address = create_multicast_socket(self._group, self._port)
+        self._socket, address = create_multicast_socket(self._group,
+                                                        self._port)
 
         # Store group access information
         self._target = (address, self._port)
