@@ -8,7 +8,7 @@ Calls services according to the given method name and parameters
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.3.0
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -29,7 +29,7 @@ Calls services according to the given method name and parameters
 """
 
 # Module version
-__version_info__ = (0, 3, 0)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -37,18 +37,18 @@ __docformat__ = "restructuredtext en"
 
 # ------------------------------------------------------------------------------
 
-# Remote Services constants
-import pelix.remote
-import pelix.remote.beans as beans
-
-# HTTP constants
-import pelix.http
-
 # iPOPO decorators
 from pelix.ipopo.decorators import ComponentFactory, Requires, Provides, \
     BindField, Property, Validate, Invalidate, Instantiate, UnbindField
 from pelix.utilities import to_str
 
+# Pelix constants
+import pelix.constants
+import pelix.framework
+import pelix.http
+import pelix.remote
+import pelix.remote.beans as beans
+
 # Standard library
 import json
 import logging
@@ -56,11 +56,12 @@ import threading
 
 try:
     # Python 3
+    # pylint: disable=F0401,E0611
     import http.client as httplib
     from urllib.parse import urljoin
-
 except ImportError:
     # Python 2
+    # pylint: disable=F0401
     import httplib
     from urlparse import urljoin
 
@@ -70,6 +71,7 @@ _logger = logging.getLogger(__name__)
 
 # ------------------------------------------------------------------------------
 
+
 @ComponentFactory('pelix-remote-dispatcher-factory')
 @Provides(pelix.remote.SERVICE_DISPATCHER)
 @Requires('_exporters', pelix.remote.SERVICE_EXPORT_PROVIDER, True, True)
@@ -110,20 +112,19 @@ class Dispatcher(object):
         self.__service_uids = {}
         self.__exporters_lock = threading.Lock()
 
-
     @Validate
     def _validate(self, context):
         """
         Component validated
         """
         # Get the framework UID
-        self._fw_uid = context.get_property(pelix.framework.FRAMEWORK_UID)
+        self._fw_uid = context.get_property(pelix.constants.FRAMEWORK_UID)
         self._context = context
 
         # Prepare the export LDAP filter
         ldapfilter = '(|({0}=*)({1}=*))' \
-                            .format(pelix.remote.PROP_EXPORTED_CONFIGS,
-                                    pelix.remote.PROP_EXPORTED_INTERFACES)
+            .format(pelix.remote.PROP_EXPORTED_CONFIGS,
+                    pelix.remote.PROP_EXPORTED_INTERFACES)
 
         # Export existing services
         existing_ref = context.get_all_service_references(None, ldapfilter)
@@ -134,7 +135,6 @@ class Dispatcher(object):
         # Register a service listener, to update the exported services state
         context.add_service_listener(self, ldapfilter)
 
-
     @Invalidate
     def _invalidate(self, context):
         """
@@ -145,7 +145,6 @@ class Dispatcher(object):
         self._context = None
         self._fw_uid = None
 
-
     def _compute_endpoint_name(self, properties):
         """
         Computes the end point name according to service properties
@@ -159,6 +158,19 @@ class Dispatcher(object):
 
         return name
 
+    def _check_name_reuse(self, name):
+        """
+        Checks if a service was waiting to reuse an endpoint name
+
+        :param name: The endpoint name to reuse
+        """
+        ldap_filter = "({0}={1})".format(pelix.remote.PROP_ENDPOINT_NAME, name)
+        _logger.info("Checking name reuse: %s", ldap_filter)
+        svc_ref = self._context.get_service_reference(None, ldap_filter)
+        _logger.info("Found svc_ref=%s", svc_ref)
+        if svc_ref is not None:
+            # A service wants to be exported with the given endpoint name
+            self.__export_service(svc_ref)
 
     def service_changed(self, event):
         """
@@ -185,12 +197,11 @@ class Dispatcher(object):
                                           event.get_previous_properties())
 
             elif svc_ref in self.__service_uids and \
-                    (kind == pelix.framework.ServiceEvent.UNREGISTERING or \
+                    (kind == pelix.framework.ServiceEvent.UNREGISTERING or
                      kind == pelix.framework.ServiceEvent.MODIFIED_ENDMATCH):
                 # Service is updated or unregistering
                 self.__unexport_service(svc_ref)
 
-
     def __export_service(self, svc_ref):
         """
         Exports the given service using all available matching providers
@@ -257,7 +268,6 @@ class Dispatcher(object):
             for listener in self._listeners[:]:
                 listener.endpoints_added(endpoints)
 
-
     def __update_service(self, svc_ref, old_properties):
         """
         Service updated, notify exporters
@@ -270,6 +280,7 @@ class Dispatcher(object):
             # No known UID
             return
 
+        names = set()
         for uid in uids:
             try:
                 # Get its exporter and bean
@@ -287,7 +298,8 @@ class Dispatcher(object):
                 # TODO: check configuration change (can be an unexport)
 
                 # Compute the previous name
-                new_name = self._compute_endpoint_name(svc_ref.get_properties())
+                new_name = \
+                    self._compute_endpoint_name(svc_ref.get_properties())
 
                 try:
                     exporter.update_export(endpoint, new_name, old_properties)
@@ -299,6 +311,7 @@ class Dispatcher(object):
                     del self.__uid_exporter[endpoint.uid]
                     del self.__endpoints[endpoint.uid]
                     exporter.unexport_service(endpoint)
+                    names.add(endpoint.name)
 
                     # Call listeners (out of the lock)
                     if self._listeners:
@@ -311,6 +324,9 @@ class Dispatcher(object):
                         for listener in self._listeners:
                             listener.endpoint_updated(endpoint, old_properties)
 
+        # Check if a service wanted to export an endpoint with the given name
+        for name in names:
+            self._check_name_reuse(name)
 
     def __unexport_service(self, svc_ref):
         """
@@ -326,6 +342,7 @@ class Dispatcher(object):
             # No known UID
             return
 
+        names = set()
         for uid in uids:
             try:
                 # Remove from storage
@@ -339,6 +356,7 @@ class Dispatcher(object):
             else:
                 # Delete endpoint
                 exporter.unexport_service(endpoint)
+                names.add(endpoint.name)
 
                 # Call listeners
                 if self._listeners:
@@ -349,7 +367,9 @@ class Dispatcher(object):
                         except Exception as ex:
                             _logger.error("Error notifying listener: %s", ex)
 
-
+        # Check if a service wanted to export an endpoint with the given name
+        for name in names:
+            self._check_name_reuse(name)
 
     @BindField('_listeners')
     def _bind_listener(self, field, listener, svc_ref):
@@ -365,7 +385,6 @@ class Dispatcher(object):
                 _logger.exception("Error notifying newly bound listener: %s",
                                   ex)
 
-
     @BindField('_exporters', if_valid=True)
     def _bind_exporter(self, field, exporter, svc_ref):
         """
@@ -397,7 +416,6 @@ class Dispatcher(object):
                         for listener in self._listeners[:]:
                             listener.endpoints_added([endpoint])
 
-
     @UnbindField('_exporters')
     def _unbind_exporter(self, field, exporter, svc_ref):
         """
@@ -433,11 +451,9 @@ class Dispatcher(object):
                 for endpoint in removed_endpoints:
                     try:
                         listener.endpoint_removed(endpoint)
-
                     except Exception as ex:
                         _logger.error("Error notifying listener: %s", ex)
 
-
     def get_endpoint(self, uid):
         """
         Retrieves an end point description, selected by its UID.
@@ -448,7 +464,6 @@ class Dispatcher(object):
         """
         return self.__endpoints.get(uid)
 
-
     def get_endpoints(self, kind=None, name=None):
         """
         Retrieves all end points matching the given kind and/or name
@@ -475,6 +490,7 @@ class Dispatcher(object):
 
 # -----------------------------------------------------------------------------
 
+
 @ComponentFactory(pelix.remote.FACTORY_REGISTRY_SERVLET)
 @Provides(pelix.http.HTTP_SERVLET)
 @Provides(pelix.remote.SERVICE_DISPATCHER_SERVLET, "_controller")
@@ -508,14 +524,13 @@ class RegistryServlet(object):
         # Ports of exposing servers
         self._ports = []
 
-
     @Validate
     def _validate(self, context):
         """
         Component validated
         """
         # Get the framework UID
-        self._fw_uid = context.get_property(pelix.framework.FRAMEWORK_UID)
+        self._fw_uid = context.get_property(pelix.constants.FRAMEWORK_UID)
 
         # Normalize the path
         self._path = '/{0}/'.format('/'.join(part
@@ -525,7 +540,6 @@ class RegistryServlet(object):
         _logger.debug("Dispatcher servlet for %s on %s", self._fw_uid,
                       self._path)
 
-
     @Invalidate
     def _invalidate(self, context):
         """
@@ -534,7 +548,6 @@ class RegistryServlet(object):
         # Clean up
         self._fw_uid = None
 
-
     def __grab_data(self, host, port, path):
         """
         Sends a HTTP request to the server at (host, port), on the given path.
@@ -574,7 +587,6 @@ class RegistryServlet(object):
             _logger.error("Error reading the response of the dispatcher: %s",
                           ex)
 
-
     def _make_endpoint_dict(self, endpoint):
         """
         Converts the end point into a dictionary
@@ -592,7 +604,6 @@ class RegistryServlet(object):
                 "specifications": endpoint.specifications,
                 "properties": properties}
 
-
     def _make_endpoint_bean(self, endpoint_dict, host=None):
         """
         Convers an endpoint dictionary into an ImportEndpoint bean
@@ -602,18 +613,18 @@ class RegistryServlet(object):
         :return: An ImportEndpoint bean
         """
         # Create the end point bean
-        endpoint = pelix.remote.beans.ImportEndpoint(endpoint_dict['uid'],
-                                             endpoint_dict['sender'],
-                                             endpoint_dict['configurations'],
-                                             endpoint_dict['name'],
-                                             endpoint_dict['specifications'],
-                                             endpoint_dict['properties'])
+        endpoint = pelix.remote.beans.ImportEndpoint(
+            endpoint_dict['uid'],
+            endpoint_dict['sender'],
+            endpoint_dict['configurations'],
+            endpoint_dict['name'],
+            endpoint_dict['specifications'],
+            endpoint_dict['properties'])
 
         # Set the host address
         endpoint.server = host
         return endpoint
 
-
     def bound_to(self, path, parameters):
         """
         This servlet has been bound to a server
@@ -629,7 +640,6 @@ class RegistryServlet(object):
             # Activate the service, we're bound to a server
             self._controller = True
 
-
     def unbound_from(self, path, parameters):
         """
         This servlet has been unbound from a server
@@ -646,7 +656,6 @@ class RegistryServlet(object):
             if not self._ports:
                 self._controller = False
 
-
     def do_GET(self, request, response):
         """
         Handles a GET request
@@ -698,9 +707,9 @@ class RegistryServlet(object):
 
         else:
             # Unknown
-            response.send_content(404, "Unhandled path {0}"\
-                                       .format(request.get_path()),
-                                  "text/plain")
+            response.send_content(404,
+                                  "Unhandled path {0}"
+                                  .format(request.get_path()), "text/plain")
             return
 
         # Convert the result to JSON
@@ -709,7 +718,6 @@ class RegistryServlet(object):
         # Send the result
         response.send_content(200, data, 'application/json')
 
-
     def do_POST(self, request, response):
         """
         Handles a POST request
@@ -737,7 +745,6 @@ class RegistryServlet(object):
         # We got the end points
         response.send_content(200, 'OK', 'text/plain')
 
-
     def get_access(self):
         """
         Returns the port and path to access this servlet with the first
@@ -747,8 +754,7 @@ class RegistryServlet(object):
         :return: A tuple: (port, path) or None
         """
         if self._ports:
-            return (self._ports[0], self._path)
-
+            return self._ports[0], self._path
 
     def grab_endpoint(self, host, port, path, uid):
         """
@@ -778,7 +784,6 @@ class RegistryServlet(object):
         # Create the end point bean
         return self._make_endpoint_bean(endpoint_dict, host)
 
-
     def send_discovered(self, host, port, path):
         """
         Sends a "discovered" HTTP POST request to the dispatcher servlet of the
@@ -795,10 +800,9 @@ class RegistryServlet(object):
 
         # Make the path to /endpoints
         if path[-1] != '/':
-            path = path + '/'
+            path += '/'
         path = urljoin(path, 'endpoints')
 
-
         # Request the end points
         try:
             conn = httplib.HTTPConnection(host, port)
