@@ -8,7 +8,7 @@ Based on a modified version of the 3rd-party package jsonrpclib-pelix.
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.3.0
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -29,7 +29,7 @@ Based on a modified version of the 3rd-party package jsonrpclib-pelix.
 """
 
 # Module version
-__version_info__ = (0, 3, 0)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -38,7 +38,7 @@ __docformat__ = "restructuredtext en"
 # ------------------------------------------------------------------------------
 
 # JSON-RPC module
-import jsonrpclib
+import jsonrpclib.jsonrpc
 from jsonrpclib.SimpleJSONRPCServer import SimpleJSONRPCDispatcher
 
 # iPOPO decorators
@@ -66,6 +66,7 @@ _logger = logging.getLogger(__name__)
 
 # ------------------------------------------------------------------------------
 
+
 class _JsonRpcServlet(SimpleJSONRPCDispatcher):
     """
     A JSON-RPC servlet that can be registered in the Pelix HTTP service
@@ -84,7 +85,6 @@ class _JsonRpcServlet(SimpleJSONRPCDispatcher):
         # Make a link to the dispatch method
         self._dispatch_method = dispatch_method
 
-
     def _simple_dispatch(self, name, params):
         """
         Dispatch method
@@ -92,11 +92,13 @@ class _JsonRpcServlet(SimpleJSONRPCDispatcher):
         try:
             # Internal method
             return self.funcs[name](*params)
-
         except KeyError:
             # Other method
-            return self._dispatch_method(name, params)
+            pass
 
+        # Call the other method outside the except block, to avoid messy logs
+        # in case of error
+        return self._dispatch_method(name, params)
 
     def do_POST(self, request, response):
         """
@@ -121,6 +123,7 @@ class _JsonRpcServlet(SimpleJSONRPCDispatcher):
 
 # ------------------------------------------------------------------------------
 
+
 @ComponentFactory(pelix.remote.FACTORY_TRANSPORT_JSONRPC_EXPORTER)
 @Provides(pelix.remote.SERVICE_EXPORT_PROVIDER)
 @Requires('_http', pelix.http.HTTP_SERVICE)
@@ -148,7 +151,6 @@ class JsonRpcServiceExporter(commons.AbstractRpcServiceExporter):
         # JSON-RPC servlet
         self._servlet = None
 
-
     def get_access(self):
         """
         Retrieves the URL to access this component
@@ -156,7 +158,6 @@ class JsonRpcServiceExporter(commons.AbstractRpcServiceExporter):
         port = self._http.get_access()[1]
         return "http://{{server}}:{0}{1}".format(port, self._path)
 
-
     def make_endpoint_properties(self, svc_ref, name, fw_uid):
         """
         Prepare properties for the ExportEndpoint to be created
@@ -168,7 +169,6 @@ class JsonRpcServiceExporter(commons.AbstractRpcServiceExporter):
         """
         return {PROP_JSONRPC_URL: self.get_access()}
 
-
     @Validate
     def validate(self, context):
         """
@@ -181,7 +181,6 @@ class JsonRpcServiceExporter(commons.AbstractRpcServiceExporter):
         self._servlet = _JsonRpcServlet(self.dispatch)
         self._http.register_servlet(self._path, self._servlet)
 
-
     @Invalidate
     def invalidate(self, context):
         """
@@ -198,6 +197,7 @@ class JsonRpcServiceExporter(commons.AbstractRpcServiceExporter):
 
 # ------------------------------------------------------------------------------
 
+
 class _ServiceCallProxy(object):
     """
     Service call proxy
@@ -212,7 +212,6 @@ class _ServiceCallProxy(object):
         self.__name = name
         self.__url = url
 
-
     def __getattr__(self, name):
         """
         Prefixes the requested attribute name by the endpoint name
@@ -243,7 +242,6 @@ class JsonRpcServiceImporter(commons.AbstractRpcServiceImporter):
         # Component properties
         self._kinds = None
 
-
     def make_service_proxy(self, endpoint):
         """
         Creates the proxy for the given ImportEndpoint
@@ -270,7 +268,6 @@ class JsonRpcServiceImporter(commons.AbstractRpcServiceImporter):
         # Return the proxy
         return _ServiceCallProxy(endpoint.name, access_url)
 
-
     def clear_service_proxy(self, endpoint):
         """
         Destroys the proxy made for the given ImportEndpoint
