@@ -8,7 +8,7 @@ Based on standard package xmlrpclib
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.3.0
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -29,7 +29,7 @@ Based on standard package xmlrpclib
 """
 
 # Module version
-__version_info__ = (0, 3, 0)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -53,11 +53,13 @@ import logging
 # XML RPC modules
 try:
     # Python 3
+    # pylint: disable=F0401
     from xmlrpc.server import SimpleXMLRPCDispatcher
     import xmlrpc.client as xmlrpclib
 
 except ImportError:
     # Python 2
+    # pylint: disable=F0401
     from SimpleXMLRPCServer import SimpleXMLRPCDispatcher
     import xmlrpclib
 
@@ -73,6 +75,7 @@ _logger = logging.getLogger(__name__)
 
 # ------------------------------------------------------------------------------
 
+
 class _XmlRpcServlet(SimpleXMLRPCDispatcher):
     """
     A XML-RPC servlet that can be registered in the Pelix HTTP service
@@ -92,7 +95,6 @@ class _XmlRpcServlet(SimpleXMLRPCDispatcher):
         # Make a link to the dispatch method
         self._dispatch_method = dispatch_method
 
-
     def _simple_dispatch(self, name, params):
         """
         Dispatch method
@@ -100,11 +102,13 @@ class _XmlRpcServlet(SimpleXMLRPCDispatcher):
         try:
             # Internal method
             return self.funcs[name](*params)
-
         except KeyError:
             # Other method
-            return self._dispatch_method(name, params)
+            pass
 
+        # Call the other method outside the except block, to avoid messy logs
+        # in case of error
+        return self._dispatch_method(name, params)
 
     def do_POST(self, request, response):
         """
@@ -124,6 +128,7 @@ class _XmlRpcServlet(SimpleXMLRPCDispatcher):
 
 # ------------------------------------------------------------------------------
 
+
 @ComponentFactory(pelix.remote.FACTORY_TRANSPORT_XMLRPC_EXPORTER)
 @Provides(pelix.remote.SERVICE_EXPORT_PROVIDER)
 @Requires('_http', pelix.http.HTTP_SERVICE)
@@ -151,7 +156,6 @@ class XmlRpcServiceExporter(commons.AbstractRpcServiceExporter):
         # XML-RPC servlet
         self._servlet = None
 
-
     def get_access(self):
         """
         Retrieves the URL to access this component
@@ -159,7 +163,6 @@ class XmlRpcServiceExporter(commons.AbstractRpcServiceExporter):
         port = self._http.get_access()[1]
         return "http://{{server}}:{0}{1}".format(port, self._path)
 
-
     def make_endpoint_properties(self, svc_ref, name, fw_uid):
         """
         Prepare properties for the ExportEndpoint to be created
@@ -171,7 +174,6 @@ class XmlRpcServiceExporter(commons.AbstractRpcServiceExporter):
         """
         return {PROP_XMLRPC_URL: self.get_access()}
 
-
     @Validate
     def validate(self, context):
         """
@@ -184,7 +186,6 @@ class XmlRpcServiceExporter(commons.AbstractRpcServiceExporter):
         self._servlet = _XmlRpcServlet(self.dispatch)
         self._http.register_servlet(self._path, self._servlet)
 
-
     @Invalidate
     def invalidate(self, context):
         """
@@ -201,6 +202,7 @@ class XmlRpcServiceExporter(commons.AbstractRpcServiceExporter):
 
 # ------------------------------------------------------------------------------
 
+
 class _ServiceCallProxy(object):
     """
     Service call proxy
@@ -215,15 +217,14 @@ class _ServiceCallProxy(object):
         self.__name = name
         self.__url = url
 
-
     def __getattr__(self, name):
         """
         Prefixes the requested attribute name by the endpoint name
         """
         # Make a proxy for this call
-        # This is an ugly trick to handle multithreaded calls, as the underlying
-        # proxy re-uses the same connection when possible: sometimes it means
-        # sending a request before retrieving a result
+        # This is an ugly trick to handle multithreaded calls, as the
+        # underlying proxy re-uses the same connection when possible: sometimes
+        # it means sending a request before retrieving a result
         proxy = xmlrpclib.ServerProxy(self.__url, allow_none=True)
         return getattr(proxy, "{0}.{1}".format(self.__name, name))
 
@@ -246,7 +247,6 @@ class XmlRpcServiceImporter(commons.AbstractRpcServiceImporter):
         # Component properties
         self._kinds = None
 
-
     def make_service_proxy(self, endpoint):
         """
         Creates the proxy for the given ImportEndpoint
@@ -273,7 +273,6 @@ class XmlRpcServiceImporter(commons.AbstractRpcServiceImporter):
         # Return the proxy
         return _ServiceCallProxy(endpoint.name, access_url)
 
-
     def clear_service_proxy(self, endpoint):
         """
         Destroys the proxy made for the given ImportEndpoint
