@@ -6,7 +6,7 @@ FileInstall: Polls for changes on files in a directory and notifies listeners
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.1
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -27,13 +27,13 @@ FileInstall: Polls for changes on files in a directory and notifies listeners
 """
 
 # Module version
-__version_info__ = (0, 1, 0)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
 __docformat__ = "restructuredtext en"
 
-#-------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 # Pelix
 from pelix.ipopo.decorators import ComponentFactory, Provides, Requires, \
@@ -48,11 +48,12 @@ import os
 import threading
 import zlib
 
-#-------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
 
 _logger = logging.getLogger(__name__)
 
-#-------------------------------------------------------------------------------
+# ------------------------------------------------------------------------------
+
 
 @ComponentFactory()
 @Provides(services.SERVICE_FILEINSTALL)
@@ -81,8 +82,8 @@ class FileInstall(object):
         self.__lock = threading.RLock()
 
         # Single thread task pool to notify listeners
-        self.__pool = pelix.threadpool.ThreadPool(1,
-                                                  logname="FileInstallNotifier")
+        self.__pool = pelix.threadpool.ThreadPool(
+            1, logname="FileInstallNotifier")
 
         # 1 thread per watched folder (folder -> Thread)
         self.__threads = {}
@@ -93,7 +94,6 @@ class FileInstall(object):
         # Validation flag
         self.__validated = False
 
-
     @Validate
     def _validate(self, context):
         """
@@ -106,7 +106,6 @@ class FileInstall(object):
             # Update the flag
             self.__validated = True
 
-
     @Invalidate
     def _invalidate(self, context):
         """
@@ -131,7 +130,6 @@ class FileInstall(object):
             self.__stoppers.clear()
             self.__threads.clear()
 
-
     @BindField('_listeners')
     def _bind_listener(self, _, svc, svc_ref):
         """
@@ -143,7 +141,6 @@ class FileInstall(object):
                 # Register the listener for this service
                 self.add_listener(folder, svc)
 
-
     @UpdateField('_listeners')
     def _update_field(self, _, svc, svc_ref, old_props):
         """
@@ -158,7 +155,6 @@ class FileInstall(object):
                 self.remove_listener(old_folder, svc)
                 self.add_listener(new_folder, svc)
 
-
     @UnbindField('_listeners')
     def _unbind_listener(self, _, svc, svc_ref):
         """
@@ -170,7 +166,6 @@ class FileInstall(object):
                 # Remove the listener
                 self.remove_listener(folder, svc)
 
-
     def add_listener(self, folder, listener):
         """
         Manual registration of a folder listener
@@ -192,9 +187,9 @@ class FileInstall(object):
                     # Start a new thread
                     event = self.__stoppers[folder] = threading.Event()
                     thread = threading.Thread(
-                                          target=self.__watch,
-                                          args=(folder, event),
-                                          name="FileInstall-{0}".format(folder))
+                        target=self.__watch,
+                        args=(folder, event),
+                        name="FileInstall-{0}".format(folder))
                     thread.daemon = True
                     self.__threads[folder] = thread
                     thread.start()
@@ -204,7 +199,6 @@ class FileInstall(object):
 
             return False
 
-
     def remove_listener(self, folder, listener):
         """
         Manual unregistration of a folder listener.
@@ -233,7 +227,6 @@ class FileInstall(object):
                     # No more listener for this folder
                     del self._folder_listeners[folder]
 
-
     def __notify(self, folder, added, updated, deleted):
         """
         Notifies listeners that files of a folder has been modified
@@ -259,7 +252,6 @@ class FileInstall(object):
             except Exception as ex:
                 _logger.exception("Error notifying a folder listener: %s", ex)
 
-
     def __get_checksum(self, filepath):
         """
         Returns the checksum (Adler32) of the given file
@@ -274,7 +266,6 @@ class FileInstall(object):
             # Return the checksum of the given file
             return zlib.adler32(filep.read())
 
-
     def __get_file_info(self, folder, filename):
         """
         Returns the (mtime, checksum) tuple for the given file
@@ -286,8 +277,7 @@ class FileInstall(object):
         :raise IOError: File not readable
         """
         filepath = os.path.join(folder, filename)
-        return (os.path.getmtime(filepath), self.__get_checksum(filepath))
-
+        return os.path.getmtime(filepath), self.__get_checksum(filepath)
 
     def __check_different(self, folder, filename, file_info, updated):
         """
@@ -296,7 +286,8 @@ class FileInstall(object):
         :param folder: Path to the parent folder
         :param filename: Base name of the file
         :param file_info: Current information about the file
-        :param updated: Set of updated files, where the file name might be added
+        :param updated: Set of updated files, where the file name might be
+                        added
         :return: The (updated) file information tuple
         :raise OSError: File not accessible
         :raise IOError: File not readable
@@ -322,12 +313,11 @@ class FileInstall(object):
 
         if previous_checksum == checksum:
             # No real modification, update file info
-            return (mtime, checksum)
+            return mtime, checksum
 
         # File modified
         updated.add(filename)
-        return (mtime, checksum)
-
+        return mtime, checksum
 
     def __watch(self, folder, stopper):
         """
