@@ -9,7 +9,7 @@ service
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.1.1
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -30,7 +30,7 @@ service
 """
 
 # Module version
-__version_info__ = (0, 1, 1)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -48,6 +48,7 @@ import pelix.services
 
 # ------------------------------------------------------------------------------
 
+
 @ComponentFactory("configadmin-shell-commands-factory")
 @Requires("_config_admin", pelix.services.SERVICE_CONFIGURATION_ADMIN)
 @Provides(SERVICE_SHELL_COMMAND)
@@ -74,14 +75,12 @@ class ConfigAdminCommands(object):
         # Clean up
         self._configs.clear()
 
-
     def get_namespace(self):
         """
         Retrieves the name space of this command handler
         """
         return "config"
 
-
     def get_methods(self):
         """
         Retrieves the list of tuples (command, method) for this command handler
@@ -92,7 +91,6 @@ class ConfigAdminCommands(object):
                 ("delete", self.delete),
                 ("list", self.list)]
 
-
     def create(self, io_handler, factory_pid, **kwargs):
         """
         Creates a factory configuration
@@ -107,7 +105,6 @@ class ConfigAdminCommands(object):
             # Update it immediately if some properties are already set
             config.update(kwargs)
 
-
     def update(self, io_handler, pid, **kwargs):
         """
         Updates a configuration
@@ -133,7 +130,6 @@ class ConfigAdminCommands(object):
         # Update configuration
         config.update(new_properties)
 
-
     def reload(self, io_handler, pid):
         """
         Reloads the configuration with the given PID from the persistence
@@ -149,7 +145,6 @@ class ConfigAdminCommands(object):
             # Log errors
             io_handler.write_line("Error reloading {0}: {1}", pid, ex)
 
-
     def delete(self, io_handler, pid):
         """
         Deletes a configuration
@@ -162,7 +157,6 @@ class ConfigAdminCommands(object):
             # Configuration was unknown
             pass
 
-
     def list(self, io_handler, pid=None):
         """
         Lists known configurations
@@ -189,7 +183,8 @@ class ConfigAdminCommands(object):
             factory_pid = config.get_factory_pid()
             if factory_pid:
                 lines.append('\tFactory PID: {0}'.format(factory_pid))
-            lines.append('\tLocation: {0}'.format(config.get_bundle_location()))
+            lines.append('\tLocation: {0}'
+                         .format(config.get_bundle_location()))
 
             try:
                 properties = config.get_properties()
