@@ -9,7 +9,7 @@ available.
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.1.4
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -30,7 +30,7 @@ available.
 """
 
 # Module version
-__version_info__ = (0, 1, 4)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -59,7 +59,6 @@ try:
     import readline
     readline.parse_and_bind('tab: complete')
     readline.set_completer(None)
-
 except ImportError:
     # Readline is missing, not critical
     readline = None
@@ -67,12 +66,12 @@ except ImportError:
 # Before Python 3, input() was raw_input()
 if sys.version_info[0] < 3:
     safe_input = raw_input
-
 else:
     safe_input = input
 
 # ------------------------------------------------------------------------------
 
+
 class InteractiveShell(object):
     """
     The interactive shell handler
@@ -101,7 +100,6 @@ class InteractiveShell(object):
         # Register as a service listener
         self._context.add_service_listener(self, None, SERVICE_SHELL)
 
-
     def _readline_prompt(self):
         """
         Prompt using the readline module (no pre-flush)
@@ -111,7 +109,6 @@ class InteractiveShell(object):
         sys.stdout.flush()
         return safe_input(self._shell.get_ps1())
 
-
     def _normal_prompt(self):
         """
         Flushes the prompt before requesting the input
@@ -122,7 +119,6 @@ class InteractiveShell(object):
         sys.stdout.flush()
         return safe_input()
 
-
     def loop_input(self, on_quit=None):
         """
         Reads the standard input until the shell session is stopped
@@ -135,7 +131,7 @@ class InteractiveShell(object):
 
             # Set up the prompt
             prompt = self._readline_prompt if readline is not None \
-                        else self._normal_prompt
+                else self._normal_prompt
 
             while not self._stop_event.is_set():
                 # Wait for the shell to be there
@@ -172,7 +168,6 @@ class InteractiveShell(object):
             # Call a handler if needed
             on_quit()
 
-
     def readline_completer(self, text, state):
         """
         A completer for the readline library
@@ -204,10 +199,11 @@ class InteractiveShell(object):
                                      if namespace.startswith(prefix))
 
                 # ... then commands in those name spaces
-                possibilities.extend('{0}.{1}'.format(namespace, command)
-                            for namespace in namespaces if namespace is not None
-                            for command in self._shell.get_commands(namespace)
-                            if command.startswith(prefix))
+                possibilities.extend(
+                    '{0}.{1}'.format(namespace, command)
+                    for namespace in namespaces if namespace is not None
+                    for command in self._shell.get_commands(namespace)
+                    if command.startswith(prefix))
 
                 # Filter methods according to the prefix
                 self._readline_matches = possibilities
@@ -222,7 +218,6 @@ class InteractiveShell(object):
             # Next try
             return self._readline_matches[state]
 
-
     def search_shell(self):
         """
         Looks for a shell service
@@ -236,7 +231,6 @@ class InteractiveShell(object):
             if reference is not None:
                 self.set_shell(reference)
 
-
     def service_changed(self, event):
         """
         Called by Pelix when an events changes
@@ -257,7 +251,6 @@ class InteractiveShell(object):
                 # Request for a new binding
                 self.search_shell()
 
-
     def set_shell(self, svc_ref):
         """
         Binds the given shell service.
@@ -279,7 +272,6 @@ class InteractiveShell(object):
             # Set the flag
             self._shell_event.set()
 
-
     def clear_shell(self):
         """
         Unbinds the active shell service
@@ -300,7 +292,6 @@ class InteractiveShell(object):
             self._shell_ref = None
             self._shell = None
 
-
     def stop(self):
         """
         Clears all members
@@ -320,6 +311,7 @@ class InteractiveShell(object):
 
 # ------------------------------------------------------------------------------
 
+
 @BundleActivator
 class Activator(object):
     """
@@ -333,7 +325,6 @@ class Activator(object):
         self._shell = None
         self._thread = None
 
-
     def start(self, context):
         """
         Bundle started
@@ -343,13 +334,13 @@ class Activator(object):
 
         # Run the loop thread
         self._thread = threading.Thread(target=self._shell.loop_input,
-                                        args=[self._quit])
+                                        args=[self._quit],
+                                        name="Pelix-Shell-TextConsole")
         # Set the thread as a daemon, to let it be killed by the interpreter
         # once all other threads stopped.
         self._thread.daemon = True
         self._thread.start()
 
-
     def stop(self, context):
         """
         Bundle stopped
@@ -357,7 +348,6 @@ class Activator(object):
         self._cleanup()
         self._context = None
 
-
     def _quit(self):
         """
         Called when the shell session has ended
@@ -369,7 +359,6 @@ class Activator(object):
         if self._context is not None:
             self._context.get_bundle(0).stop()
 
-
     def _cleanup(self):
         """
         Cleans up the members
@@ -383,6 +372,7 @@ class Activator(object):
 
 # ------------------------------------------------------------------------------
 
+
 def main():
     """
     Entry point
@@ -392,11 +382,12 @@ def main():
                             'pelix.shell.console', 'pelix.shell.ipopo'),
                            None, True, True, True)
 
-
 if __name__ == '__main__':
-    # Ran as a script:
     # Prepare the logger
-    logging.basicConfig(level=logging.WARNING)
+    if '-v' in sys.argv or '--verbose' in sys.argv:
+        logging.basicConfig(level=logging.DEBUG)
+    else:
+        logging.basicConfig(level=logging.WARNING)
 
     # Run the entry point
     main()
