@@ -8,7 +8,7 @@ Provides the basic command parsing and execution support to make a Pelix shell.
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.2.5
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -29,7 +29,7 @@ Provides the basic command parsing and execution support to make a Pelix shell.
 """
 
 # Module version
-__version_info__ = (0, 2, 5)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -72,6 +72,7 @@ _logger = logging.getLogger(__name__)
 
 # ------------------------------------------------------------------------------
 
+
 def _find_assignment(arg_token):
     """
     Find the first non-escaped assignment in the given argument token.
@@ -147,6 +148,7 @@ def _split_ns_command(cmd_token):
 
 # ------------------------------------------------------------------------------
 
+
 class IOHandler(object):
     """
     Handles I/O operations between the command handler and the client
@@ -184,7 +186,6 @@ class IOHandler(object):
         else:
             self.prompt = self._prompt
 
-
     def _prompt(self, prompt=None):
         """
         Reads a line written by the user
@@ -200,7 +201,6 @@ class IOHandler(object):
         # Read the line
         return to_str(self.input.readline())
 
-
     def _write_bytes(self, data):
         """
         Converts the given data then writes it
@@ -210,7 +210,6 @@ class IOHandler(object):
         """
         self.output.write(to_bytes(data, self.encoding))
 
-
     def _write_str(self, data):
         """
         Converts the given data then writes it
@@ -220,7 +219,6 @@ class IOHandler(object):
         """
         self.output.write(to_str(data, self.encoding))
 
-
     def write_line(self, line, *args, **kwargs):
         """
         Formats and writes a line to the output
@@ -248,7 +246,6 @@ class IOHandler(object):
 
         self.flush()
 
-
     def write_line_no_feed(self, line, *args, **kwargs):
         """
         Formats and writes a line to the output
@@ -272,6 +269,7 @@ class IOHandler(object):
 
 # ------------------------------------------------------------------------------
 
+
 class ShellUtils(object):
     """
     Utility methods for the shell
@@ -281,16 +279,15 @@ class ShellUtils(object):
         Converts a bundle state integer to a string
         """
         states = {
-                  pelix.Bundle.INSTALLED:   "INSTALLED",
-                  pelix.Bundle.ACTIVE:      "ACTIVE",
-                  pelix.Bundle.RESOLVED:    "RESOLVED",
-                  pelix.Bundle.STARTING:    "STARTING",
-                  pelix.Bundle.STOPPING:    "STOPPING",
-                  pelix.Bundle.UNINSTALLED: "UNINSTALLED"
+            pelix.Bundle.INSTALLED: "INSTALLED",
+            pelix.Bundle.ACTIVE: "ACTIVE",
+            pelix.Bundle.RESOLVED: "RESOLVED",
+            pelix.Bundle.STARTING: "STARTING",
+            pelix.Bundle.STOPPING: "STOPPING",
+            pelix.Bundle.UNINSTALLED: "UNINSTALLED"
         }
 
-        return states.get(state, "Unknown state (%d)".format(state))
-
+        return states.get(state, "Unknown state ({0})".format(state))
 
     def make_table(self, headers, lines, prefix=None):
         """
@@ -300,7 +297,8 @@ class ShellUtils(object):
         :param lines: List of table lines (N-tuples)
         :param prefix: Optional prefix for each line
         :return: The ASCII representation of the table
-        :raise ValueError: Different number of columns between headers and lines
+        :raise ValueError: Different number of columns between headers and
+                           lines
         """
         # Normalize the prefix
         prefix = str(prefix or "")
@@ -351,17 +349,17 @@ class ShellUtils(object):
         head_str = format_str.format(*headers)
 
         # Prepare the separator, according the length of the headers string
-        separator = '{0}{1}'.format(prefix, '-' * (len(head_str) - len(prefix)))
+        separator = '{0}{1}'.format(prefix,
+                                    '-' * (len(head_str) - len(prefix)))
         idx = head_str.find('|')
         while idx != -1:
             separator = '+'.join((separator[:idx], separator[idx + 1:]))
             idx = head_str.find('|', idx + 1)
 
         # Prepare the output
-        output = []
-        output.append(separator)
-        output.append(head_str)
-        output.append(separator.replace('-', '='))
+        output = [separator,
+                  head_str,
+                  separator.replace('-', '=')]
 
         # Compute the lines
         format_str = format_str.replace('^', '<')
@@ -377,6 +375,7 @@ class ShellUtils(object):
 
 # ------------------------------------------------------------------------------
 
+
 class Shell(object):
     """
     A simple shell, based on shlex.
@@ -423,6 +422,8 @@ class Shell(object):
 
         self.register_command(None, "echo", self.echo)
 
+        self.register_command(None, "loglevel", self.log_level)
+
         self.register_command(None, "help", self.print_help)
         self.register_command(None, "?", self.print_help)
 
@@ -430,7 +431,6 @@ class Shell(object):
         self.register_command(None, "close", self.quit)
         self.register_command(None, "exit", self.quit)
 
-
     def _bind_handler(self, svc_ref):
         """
         Called if a command service has been found.
@@ -460,7 +460,6 @@ class Shell(object):
         self._reference_commands[svc_ref] = (namespace, commands)
         return True
 
-
     def _unbind_handler(self, svc_ref):
         """
         Called if a command service is gone.
@@ -484,7 +483,6 @@ class Shell(object):
         del self._reference_commands[svc_ref]
         return True
 
-
     def register_command(self, namespace, command, method):
         """
         Registers the given command to the shell.
@@ -494,8 +492,8 @@ class Shell(object):
         :param namespace: The command name space.
         :param command: The shell name of the command
         :param method: The method to call
-        :return: True if the method has been registered, False if it was already
-                 known or invalid
+        :return: True if the method has been registered, False if it was
+                 already known or invalid
         """
         if method is None:
             _logger.error("No method given for %s.%s", namespace, command)
@@ -525,7 +523,6 @@ class Shell(object):
         space[command] = method
         return True
 
-
     def unregister(self, namespace, command=None):
         """
         Unregisters the given command. If command is None, the whole name space
@@ -563,7 +560,6 @@ class Shell(object):
 
         return True
 
-
     def __find_command_ns(self, command):
         """
         Returns the name spaces where the given command named is registered.
@@ -594,7 +590,6 @@ class Shell(object):
 
         return namespaces
 
-
     def get_ns_commands(self, cmd_name):
         """
         Retrieves the possible name spaces and commands associated to the given
@@ -619,7 +614,6 @@ class Shell(object):
         # Single match
         return [(namespace, command)]
 
-
     def get_ns_command(self, cmd_name):
         """
         Retrieves the name space and the command associated to the given
@@ -645,7 +639,7 @@ class Shell(object):
 
                 else:
                     # Ambiguous name
-                    raise ValueError("Multiple name spaces for {0}: {1}" \
+                    raise ValueError("Multiple name spaces for {0}: {1}"
                                      .format(command, ', '.join(spaces)))
 
             else:
@@ -655,7 +649,6 @@ class Shell(object):
         # Command found
         return namespace, command
 
-
     def execute(self, cmdline, stdin=sys.stdin, stdout=sys.stdout):
         """
         Executes the command corresponding to the given line
@@ -720,10 +713,17 @@ class Shell(object):
 
         except Exception as ex:
             # Error
-            _logger.exception("Error calling %s.%s: %s", namespace, command, ex)
+            _logger.exception("Error calling %s.%s: %s",
+                              namespace, command, ex)
             io_handler.write_line("{0}: {1}", type(ex).__name__, str(ex))
             return False
 
+        finally:
+            # Try to flush in any case
+            try:
+                io_handler.flush()
+            except:
+                pass
 
     def get_banner(self):
         """
@@ -731,14 +731,12 @@ class Shell(object):
         """
         return "** Pelix Shell prompt **\n"
 
-
     def get_ps1(self):
         """
         Returns the PS1, the basic shell prompt
         """
         return "$ "
 
-
     def get_namespaces(self):
         """
         Retrieves the list of known name spaces (without the default one)
@@ -750,7 +748,6 @@ class Shell(object):
         namespaces.sort()
         return namespaces
 
-
     def get_commands(self, namespace):
         """
         Retrieves the commands of the given name space. If *namespace* is None
@@ -773,14 +770,12 @@ class Shell(object):
             # Unknown name space
             return []
 
-
     def echo(self, io_handler, *words):
         """
         Echoes the given words
         """
         io_handler.write_line(' '.join(words))
 
-
     def bundle_details(self, io_handler, bundle_id):
         """
         Prints the details of the bundle with the given ID or name
@@ -812,14 +807,13 @@ class Shell(object):
             io_handler.write_line("Unknown bundle ID: {0}", bundle_id)
             return
 
-        lines = []
-        lines.append("ID......: {0}".format(bundle.get_bundle_id()))
-        lines.append("Name....: {0}".format(bundle.get_symbolic_name()))
-        lines.append("Version.: {0}".format(bundle.get_version()))
-        lines.append("State...: {0}".format(self._utils.bundlestate_to_str(
-                                                        bundle.get_state())))
-        lines.append("Location: {0}".format(bundle.get_location()))
-        lines.append("Published services:")
+        lines = ["ID......: {0}".format(bundle.get_bundle_id()),
+                 "Name....: {0}".format(bundle.get_symbolic_name()),
+                 "Version.: {0}".format(bundle.get_version()),
+                 "State...: {0}".format(
+                     self._utils.bundlestate_to_str(bundle.get_state())),
+                 "Location: {0}".format(bundle.get_location()),
+                 "Published services:"]
         try:
             services = bundle.get_registered_services()
             if services:
@@ -849,7 +843,6 @@ class Shell(object):
         lines.append("")
         io_handler.write('\n'.join(lines))
 
-
     def bundles_list(self, io_handler, name=None):
         """
         Lists the bundles in the framework and their state. Possibility to
@@ -870,11 +863,12 @@ class Shell(object):
                        if name in bundle.get_symbolic_name()]
 
         # Make the entries
-        lines = [[str(entry) for entry in
-                        (bundle.get_bundle_id(),
-                         bundle.get_symbolic_name(),
-                         self._utils.bundlestate_to_str(bundle.get_state()),
-                         bundle.get_version())]
+        lines = [[str(entry)
+                  for entry in (bundle.get_bundle_id(),
+                                bundle.get_symbolic_name(),
+                                self._utils.bundlestate_to_str(
+                                    bundle.get_state()),
+                                bundle.get_version())]
                  for bundle in bundles]
 
         # Print'em all
@@ -886,27 +880,25 @@ class Shell(object):
         else:
             io_handler.write_line("{0} filtered bundles", len(lines))
 
-
     def service_details(self, io_handler, service_id):
         """
         Prints the details of the service with the given ID
         """
-        svc_ref = self._context.get_service_reference(None,
-                                '({0}={1})'.format(constants.SERVICE_ID,
-                                                   service_id))
+        svc_ref = self._context.get_service_reference(
+            None, '({0}={1})'.format(constants.SERVICE_ID, service_id))
         if svc_ref is None:
             io_handler.write_line('Service not found: {0}', service_id)
             return
 
-        lines = []
-        lines.append("ID............: {0}".format(svc_ref.get_property(
-                                            constants.SERVICE_ID)))
-        lines.append("Rank..........: {0}".format(svc_ref.get_property(
-                                            constants.SERVICE_RANKING)))
-        lines.append("Specifications: {0}".format(svc_ref.get_property(
-                                            constants.OBJECTCLASS)))
-        lines.append("Bundle........: {0}".format(svc_ref.get_bundle()))
-        lines.append("Properties....:")
+        lines = [
+            "ID............: {0}".format(
+                svc_ref.get_property(constants.SERVICE_ID)),
+            "Rank..........: {0}".format(
+                svc_ref.get_property(constants.SERVICE_RANKING)),
+            "Specifications: {0}".format(
+                svc_ref.get_property(constants.OBJECTCLASS)),
+            "Bundle........: {0}".format(svc_ref.get_bundle()),
+            "Properties....:"]
         for key, value in sorted(svc_ref.get_properties().items()):
             lines.append("\t{0} = {1}".format(key, value))
 
@@ -917,7 +909,6 @@ class Shell(object):
         lines.append("")
         io_handler.write('\n'.join(lines))
 
-
     def services_list(self, io_handler, specification=None):
         """
         Lists the services in the framework. Possibility to filter on an exact
@@ -934,15 +925,16 @@ class Shell(object):
 
         if specification is not None:
             # Filter on specifications
-            references = [ref for ref in references if specification
+            references = [ref for ref in references
+                          if specification
                           in ref.get_property(constants.OBJECTCLASS)]
 
         # Construct the list of services
-        lines = [[str(entry) for entry in
-                        (ref.get_property(constants.SERVICE_ID),
-                         ref.get_property(constants.OBJECTCLASS),
-                         ref.get_bundle(),
-                         ref.get_property(constants.SERVICE_RANKING))]
+        lines = [[str(entry)
+                  for entry in (ref.get_property(constants.SERVICE_ID),
+                                ref.get_property(constants.OBJECTCLASS),
+                                ref.get_bundle(),
+                                ref.get_property(constants.SERVICE_RANKING))]
                  for ref in references]
 
         if not lines and specification:
@@ -953,7 +945,6 @@ class Shell(object):
             io_handler.write(self._utils.make_table(headers, lines))
             io_handler.write_line("{0} services registered", len(lines))
 
-
     def __extract_help(self, method):
         """
         Formats the help string for the given method
@@ -972,14 +963,14 @@ class Shell(object):
             nb_optional = len(argspec.defaults)
 
             # Let the mandatory arguments as they are
-            args = ["<{0}>".format(arg) for arg in argspec.args[2:-nb_optional]]
+            args = ["<{0}>".format(arg)
+                    for arg in argspec.args[2:-nb_optional]]
 
             # Add the other arguments
             for name, value in zip(argspec.args[-nb_optional:],
                                    argspec.defaults[-nb_optional:]):
                 if value is not None:
                     args.append('[<{0}>={1}]'.format(name, value))
-
                 else:
                     args.append('[<{0}>]'.format(name))
 
@@ -999,7 +990,6 @@ class Shell(object):
 
         return ' '.join(args), ' '.join(doc.split())
 
-
     def __print_command_help(self, io_handler, namespace, cmd_name):
         """
         Prints the documentation of the given command
@@ -1020,7 +1010,6 @@ class Shell(object):
         # Print the documentation line
         io_handler.write_line("\t\t{0}", doc)
 
-
     def __print_namespace_help(self, io_handler, namespace, cmd_name=None):
         """
         Prints the documentation of all the commands in the given name space,
@@ -1049,7 +1038,6 @@ class Shell(object):
             self.__print_command_help(io_handler, namespace, command)
             first_cmd = False
 
-
     def print_help(self, io_handler, command=None):
         """
         Prints the available methods and their documentation, or the
@@ -1083,7 +1071,8 @@ class Shell(object):
                     io_handler.write_line('\n\n')
 
                 for namespace, cmd_name in possibilities:
-                    self.__print_namespace_help(io_handler, namespace, cmd_name)
+                    self.__print_namespace_help(io_handler, namespace,
+                                                cmd_name)
 
         else:
             # Get all name spaces
@@ -1102,7 +1091,6 @@ class Shell(object):
                 self.__print_namespace_help(io_handler, namespace)
                 first_ns = False
 
-
     def properties_list(self, io_handler):
         """
         Lists the properties of the framework
@@ -1122,7 +1110,6 @@ class Shell(object):
         # Print the table
         io_handler.write(self._utils.make_table(headers, lines))
 
-
     def property_value(self, io_handler, name):
         """
         Prints the value of the given property, looking into
@@ -1135,7 +1122,6 @@ class Shell(object):
 
         io_handler.write_line(str(value))
 
-
     def environment_list(self, io_handler):
         """
         Lists the framework process environment variables
@@ -1152,14 +1138,12 @@ class Shell(object):
         # Print the table
         io_handler.write(self._utils.make_table(headers, lines))
 
-
     def environment_value(self, io_handler, name):
         """
         Prints the value of the given environment variable
         """
         io_handler.write_line(os.getenv(name))
 
-
     def threads_list(self, io_handler):
         """
         Lists the active threads and their current code line
@@ -1198,7 +1182,6 @@ class Shell(object):
         # Sort the lines
         io_handler.write('\n'.join(lines))
 
-
     def thread_details(self, io_handler, thread_id):
         """
         Prints details about the thread with the given ID (not its name)
@@ -1222,9 +1205,8 @@ class Shell(object):
             except KeyError:
                 name = "<unknown>"
 
-            lines = []
-            lines.append('Thread ID: {0} - Name: {1}'.format(thread_id, name))
-            lines.append('Stack trace:')
+            lines = ['Thread ID: {0} - Name: {1}'.format(thread_id, name),
+                     'Stack trace:']
 
             trace_lines = []
             frame = stack
@@ -1244,7 +1226,6 @@ class Shell(object):
             lines.append('')
             io_handler.write('\n'.join(lines))
 
-
     def __format_frame_info(self, frame):
         """
         Formats the given stack frame to show its position in the code and
@@ -1271,22 +1252,22 @@ class Shell(object):
             pass
 
         # File & line
-        output_lines.append('  File "{0}", line {1}, in {2}'\
+        output_lines.append('  File "{0}", line {1}, in {2}'
                             .format(filename, lineno, method_name))
 
         # Arguments
         arginfo = inspect.getargvalues(frame)
         for name in arginfo.args:
-            output_lines.append('    - {0:s} = {1}'\
-                                 .format(name, repr(frame.f_locals[name])))
+            output_lines.append('    - {0:s} = {1}'
+                                .format(name, repr(frame.f_locals[name])))
 
         if arginfo.varargs:
-            output_lines.append('    - *{0:s} = {1}'\
+            output_lines.append('    - *{0:s} = {1}'
                                 .format(arginfo.varargs,
                                         frame.f_locals[arginfo.varargs]))
 
         if arginfo.keywords:
-            output_lines.append('    - **{0:s} = {1}'\
+            output_lines.append('    - **{0:s} = {1}'
                                 .format(arginfo.keywords,
                                         frame.f_locals[arginfo.keywords]))
 
@@ -1295,12 +1276,12 @@ class Shell(object):
         if lines:
             output_lines.append('')
             prefix = '      '
-            output_lines.append('{0}{1}'.format(prefix,
-                                            '\n{0}'.format(prefix).join(lines)))
+            output_lines.append('{0}{1}'
+                                .format(prefix,
+                                        '\n{0}'.format(prefix).join(lines)))
 
         return '\n'.join(output_lines)
 
-
     def __extract_lines(self, filename, f_globals, lineno, around):
         """
         Extracts a block of lines from the given file
@@ -1349,6 +1330,33 @@ class Shell(object):
         # Return the lines
         return lines
 
+    def log_level(self, io_handler, level=None, name=None):
+        """
+        Prints/Changes log level
+        """
+        # Get the logger
+        logger = logging.getLogger(name)
+
+        # Normalize the name
+        if not name:
+            name = "Root"
+
+        if not level:
+            # Level not given: print the logger level
+            io_handler.write_line(
+                "{0} log level: {1} (real: {2})",
+                name,
+                logging.getLevelName(logger.getEffectiveLevel()),
+                logging.getLevelName(logger.level))
+
+        else:
+            # Set the logger level
+            try:
+                logger.setLevel(level.upper())
+                io_handler.write_line("New level for {0}: {1}", name, level)
+
+            except ValueError:
+                io_handler.write_line("Invalid log level: {0}", level)
 
     def quit(self, io_handler):
         """
@@ -1357,7 +1365,6 @@ class Shell(object):
         io_handler.write_line("Raising KeyboardInterrupt to stop main thread")
         raise KeyboardInterrupt()
 
-
     def __get_bundle(self, io_handler, bundle_id):
         """
         Retrieves the Bundle object with the given bundle ID. Writes errors
@@ -1377,7 +1384,6 @@ class Shell(object):
         except constants.BundleException:
             io_handler.write_line("Unknown bundle: {0}", bundle_id)
 
-
     def start(self, io_handler, bundle_id):
         """
         Starts the bundle with the given ID
@@ -1386,7 +1392,6 @@ class Shell(object):
         if bundle is not None:
             bundle.start()
 
-
     def stop(self, io_handler, bundle_id):
         """
         Stops the bundle with the given ID
@@ -1395,7 +1400,6 @@ class Shell(object):
         if bundle is not None:
             bundle.stop()
 
-
     def update(self, io_handler, bundle_id):
         """
         Updates the bundle with the given ID
@@ -1404,7 +1408,6 @@ class Shell(object):
         if bundle is not None:
             bundle.update()
 
-
     def install(self, io_handler, module_name):
         """
         Installs the bundle with the given module name
@@ -1412,7 +1415,6 @@ class Shell(object):
         bundle = self._context.install_bundle(module_name)
         io_handler.write_line("Bundle ID: {0}", bundle.get_bundle_id())
 
-
     def uninstall(self, io_handler, bundle_id):
         """
         Uninstalls the bundle with the given ID
@@ -1423,6 +1425,7 @@ class Shell(object):
 
 # ------------------------------------------------------------------------------
 
+
 @constants.BundleActivator
 class PelixActivator(object):
     """
@@ -1436,7 +1439,6 @@ class PelixActivator(object):
         self._shell_reg = None
         self._utils_reg = None
 
-
     def service_changed(self, event):
         """
         Called when a command provider service event occurred
@@ -1453,7 +1455,6 @@ class PelixActivator(object):
             # Service gone or not matching anymore
             self._shell._unbind_handler(reference)
 
-
     def start(self, context):
         """
         Bundle starting
@@ -1486,7 +1487,6 @@ class PelixActivator(object):
         except constants.BundleException as ex:
             _logger.exception("Error registering the shell service: %s", ex)
 
-
     def stop(self, context):
         """
         Bundle stopping
