@@ -8,7 +8,7 @@ Provides commands to the Pelix shell to get the state of iPOPO instances.
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.2.3
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -29,7 +29,7 @@ Provides commands to the Pelix shell to get the state of iPOPO instances.
 """
 
 # Module version
-__version_info__ = (0, 2, 3)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -52,6 +52,7 @@ _logger = logging.getLogger(__name__)
 
 # ------------------------------------------------------------------------------
 
+
 def ipopo_state_to_str(state):
     """
     Converts the state of a component instance to its string representation
@@ -60,15 +61,15 @@ def ipopo_state_to_str(state):
     :return: A string representation of the state
     """
     ipopo_states = {0: "INVALID",
-                    1:"VALID",
-                    2:"KILLED",
-                    3:"VALIDATING"
-    }
+                    1: "VALID",
+                    2: "KILLED",
+                    3: "VALIDATING"}
 
-    return ipopo_states.get(state, "Unknown state (%d)".format(state))
+    return ipopo_states.get(state, "Unknown state ({0})".format(state))
 
 # ------------------------------------------------------------------------------
 
+
 @ComponentFactory("ipopo-shell-commands-factory")
 @Requires("_ipopo", pelix.ipopo.constants.SERVICE_IPOPO)
 @Requires("_utils", pelix.shell.SERVICE_SHELL_UTILS)
@@ -85,14 +86,12 @@ class IPopoCommands(object):
         self._ipopo = None
         self._utils = None
 
-
     def get_namespace(self):
         """
         Retrieves the name space of this command handler
         """
         return "ipopo"
 
-
     def get_methods(self):
         """
         Retrieves the list of tuples (command, method) for this command handler
@@ -103,9 +102,7 @@ class IPopoCommands(object):
                 ("waiting", self.list_waitings),
                 ("instance", self.instance_details),
                 ("instantiate", self.instantiate),
-                ("kill", self.kill),
-                ]
-
+                ("kill", self.kill)]
 
     def list_factories(self, io_handler, name=None):
         """
@@ -127,7 +124,6 @@ class IPopoCommands(object):
         else:
             io_handler.write_line("{0} filtered factories", len(lines))
 
-
     def list_instances(self, io_handler, name=None):
         """
         Lists the active iPOPO component instances
@@ -150,7 +146,6 @@ class IPopoCommands(object):
         else:
             io_handler.write_line("{0} filtered components", len(instances))
 
-
     def list_waitings(self, io_handler, name=None):
         """
         Lists the components waiting to be instantiated
@@ -161,7 +156,7 @@ class IPopoCommands(object):
         if name is not None:
             # Filter components by name
             components = [component for component in components
-                         if name in component[0]]
+                          if name in component[0]]
 
         # Lines are already sorted
         lines = ((name, factory, ', '.join(missing))
@@ -174,7 +169,6 @@ class IPopoCommands(object):
         else:
             io_handler.write_line("{0} filtered components", len(components))
 
-
     def factory_details(self, io_handler, name):
         """
         Prints the details of the given component factory
@@ -187,9 +181,9 @@ class IPopoCommands(object):
                                   name, ex)
             return
 
-        lines = []
-        lines.append("Name  : {0}".format(details["name"]))
-        lines.append("Bundle: {0}".format(details["bundle"]))
+        lines = [
+            "Name  : {0}".format(details["name"]),
+            "Bundle: {0}".format(details["bundle"])]
 
         properties = details.get('properties', None)
         if properties:
@@ -216,7 +210,6 @@ class IPopoCommands(object):
 
             lines.append(self._utils.make_table(req_headers, req_lines, '\t'))
 
-
         handlers = details.get('handlers', None)
         if handlers:
             lines.append("Handlers:")
@@ -227,7 +220,6 @@ class IPopoCommands(object):
 
         io_handler.write('\n'.join(lines))
 
-
     def instance_details(self, io_handler, name):
         """
         Prints the details of the given component instance
@@ -241,15 +233,14 @@ class IPopoCommands(object):
             return
 
         # Basic information
-        lines = []
-        lines.append("Name.....: {0}".format(details["name"]))
-        lines.append("Factory..: {0}".format(details["factory"]))
-        lines.append("Bundle ID: {0}".format(details["bundle_id"]))
-        lines.append("State....: {0}".format(
-                                         ipopo_state_to_str(details["state"])))
+        lines = [
+            "Name.....: {0}".format(details["name"]),
+            "Factory..: {0}".format(details["factory"]),
+            "Bundle ID: {0}".format(details["bundle_id"]),
+            "State....: {0}".format(ipopo_state_to_str(details["state"])),
+            "Services.:"]
 
         # Provided services
-        lines.append("Services.:")
         lines.extend("\t{0}".format(svc_reference)
                      for svc_reference in details["services"].values())
 
@@ -257,7 +248,7 @@ class IPopoCommands(object):
         lines.append("Dependencies:")
         for field, infos in details["dependencies"].items():
             lines.append("\tField: {0}".format(field))
-            lines.append("\t\tSpecification: {0}"\
+            lines.append("\t\tSpecification: {0}"
                          .format(infos['specification']))
             if "filter" in infos:
                 lines.append("\t\tFilter......: {0}".format(infos["filter"]))
@@ -271,13 +262,12 @@ class IPopoCommands(object):
 
         # Properties
         lines.append("Properties:")
-        lines.append(self._utils.make_table(("Key", "Value"),
-                                sorted(details['properties'].items()), "\t"))
+        lines.append(self._utils.make_table(
+            ("Key", "Value"), sorted(details['properties'].items()), "\t"))
 
         lines.append("")
         io_handler.write('\n'.join(lines))
 
-
     def instantiate(self, io_handler, factory, name, **kwargs):
         """
         Instantiates a component of the given factory with the given name and
@@ -297,7 +287,6 @@ class IPopoCommands(object):
             io_handler.write_line("Error instantiating the component: {0}", ex)
             _logger.exception("Error instantiating the component")
 
-
     def kill(self, io_handler, name):
         """
         Kills the given component instance
