@@ -9,7 +9,7 @@ telnet or netcat.
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.1.3
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -30,7 +30,7 @@ telnet or netcat.
 """
 
 # Module version
-__version_info__ = (0, 1, 3)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # Documentation strings format
@@ -44,19 +44,22 @@ from pelix.ipopo.decorators import ComponentFactory, Requires, Property, \
 
 # Shell constants
 import pelix.shell
+import pelix.ipv6utils
 
 # Standard library
 from select import select
 import logging
 import threading
 import socket
+import sys
 
 try:
     # Python 3
+    # pylint: disable=F0401
     import socketserver
-
 except ImportError:
     # Python 2
+    # pylint: disable=F0401
     import SocketServer as socketserver
 
 # ------------------------------------------------------------------------------
@@ -65,6 +68,7 @@ _logger = logging.getLogger(__name__)
 
 # ------------------------------------------------------------------------------
 
+
 class SharedBoolean(object):
     """
     Shared boolean between objects / threads
@@ -76,7 +80,6 @@ class SharedBoolean(object):
         self._lock = threading.Lock()
         self._value = value
 
-
     def get_value(self):
         """
         Retrieves the boolean value
@@ -84,7 +87,6 @@ class SharedBoolean(object):
         with self._lock:
             return self._value
 
-
     def set_value(self, value):
         """
         Sets the boolean value
@@ -94,6 +96,7 @@ class SharedBoolean(object):
 
 # ------------------------------------------------------------------------------
 
+
 class RemoteConsole(socketserver.StreamRequestHandler):
     """
     Handles incoming connections and redirect network stream to the Pelix shell
@@ -109,7 +112,6 @@ class RemoteConsole(socketserver.StreamRequestHandler):
         self._active = active_flag
         socketserver.StreamRequestHandler.__init__(self, *args)
 
-
     def send(self, data):
         """
         Tries to send data to the client.
@@ -131,7 +133,6 @@ class RemoteConsole(socketserver.StreamRequestHandler):
             # disconnect (i.e. "echo stop 0 | nc localhost 9000")
             return False
 
-
     def handle(self):
         """
         Handles a TCP client
@@ -197,6 +198,7 @@ class RemoteConsole(socketserver.StreamRequestHandler):
 
 # ------------------------------------------------------------------------------
 
+
 class ThreadingTCPServerFamily(socketserver.ThreadingTCPServer):
     """
     Threaded TCP Server handling different address families
@@ -217,19 +219,27 @@ class ThreadingTCPServerFamily(socketserver.ThreadingTCPServer):
         socketserver.ThreadingTCPServer.__init__(self, server_address,
                                                  request_handler_class,
                                                  False)
-
         if self.address_family == socket.AF_INET6:
             # Explicitly ask to be accessible both by IPv4 and IPv6
-            # Some versions of Python don't have V6ONLY.
-            # On Linux, IPC6_V6ONLY = 26
-            opt_ipv6_only = getattr(socket, "IPV6_V6ONLY", 26)
-
             try:
-                self.socket.setsockopt(socket.IPPROTO_IPV6, opt_ipv6_only, 0)
-
+                pelix.ipv6utils.set_double_stack(self.socket)
+            except AttributeError as ex:
+                _logger.exception("System misses IPv6 constant: %s", ex)
             except socket.error as ex:
-                # Log the error
-                _logger.exception("Couldn't set IP double stack flag: %s", ex)
+                _logger.exception("Error setting up IPv6 double stack: %s", ex)
+
+    def process_request(self, request, client_address):
+        """
+        Starts a new thread to process the request, adding the client address
+        in its name.
+        """
+        thread = threading.Thread(name="RemoteShell-{0}-Client-{1}"
+                                  .format(self.server_address[1],
+                                          client_address[:2]),
+                                  target=self.process_request_thread,
+                                  args=(request, client_address))
+        thread.daemon = self.daemon_threads
+        thread.start()
 
 
 def _create_server(shell, server_address, port):
@@ -262,10 +272,11 @@ def _create_server(shell, server_address, port):
     server_thread.daemon = True
     server_thread.start()
 
-    return (server_thread, server, active_flag)
+    return server_thread, server, active_flag
 
 # ------------------------------------------------------------------------------
 
+
 @ComponentFactory(pelix.shell.FACTORY_REMOTE_SHELL)
 @Provides(pelix.shell.SERVICE_SHELL_REMOTE)
 @Requires("_shell", pelix.shell.SERVICE_SHELL)
@@ -289,15 +300,13 @@ class IPopoRemoteShell(object):
         self._server = None
         self._server_flag = None
 
-
     def get_access(self):
         """
         Implementation of the remote shell specification
 
         :return: A (host, port) tuple
         """
-        return (self._address, self._port)
-
+        return self._address, self._port
 
     def get_banner(self):
         """
@@ -311,7 +320,6 @@ class IPopoRemoteShell(object):
         return "{lines}\n{shell_banner}\niPOPO Remote Shell\n{lines}\n" \
             .format(lines=line, shell_banner=shell_banner)
 
-
     def get_ps1(self):
         """
         Returns the shell prompt
@@ -320,7 +328,6 @@ class IPopoRemoteShell(object):
         """
         return self._shell.get_ps1()
 
-
     def handle_line(self, rfile, wfile, line):
         """
         Handles the command line.
@@ -334,7 +341,6 @@ class IPopoRemoteShell(object):
         """
         return self._shell.execute(line, rfile, wfile)
 
-
     @Validate
     def validate(self, context):
         """
@@ -356,14 +362,13 @@ class IPopoRemoteShell(object):
 
         # Start the TCP server
         self._thread, self._server, self._server_flag = \
-                                _create_server(self, self._address, self._port)
+            _create_server(self, self._address, self._port)
 
         # Property update (if port was 0)
         self._port = self._server.socket.getsockname()[1]
 
         _logger.info("RemoteShell validated on port: %d", self._port)
 
-
     @Invalidate
     def invalidate(self, context):
         """
@@ -385,3 +390,103 @@ class IPopoRemoteShell(object):
         self._server_flag = None
 
         _logger.info("RemoteShell gone from port: %d", self._port)
+
+# ------------------------------------------------------------------------------
+
+
+def main(address="localhost", port=9000):
+    """
+    Starts a framework with a remote shell and starts an interactive console.
+
+    :param address: Shell binding address
+    :param port: Shell binding port
+    """
+    from pelix.ipopo.constants import use_ipopo
+    import pelix.framework
+
+    # Start a Pelix framework
+    framework = pelix.framework.create_framework(('pelix.ipopo.core',
+                                                  'pelix.shell.core',
+                                                  'pelix.shell.ipopo',
+                                                  'pelix.shell.remote'))
+    framework.start()
+    context = framework.get_bundle_context()
+
+    # Instantiate a Remote Shell
+    with use_ipopo(context) as ipopo:
+        rshell = ipopo.instantiate(pelix.shell.FACTORY_REMOTE_SHELL,
+                                   "remote-shell",
+                                   {"pelix.shell.address": address,
+                                    "pelix.shell.port": port})
+
+    # Prepare interpreter variables
+    variables = {'__name__': '__console__',
+                 '__doc__': None,
+                 '__package__': None,
+                 'framework': framework,
+                 'context': context,
+                 'use_ipopo': use_ipopo}
+
+    # Prepare a banner
+    host, port = rshell.get_access()
+    banner = "{lines}\nPython interpreter with Pelix Remote Shell\n" \
+        "Remote shell bound to: {host}:{port}\n{lines}\n" \
+        "Python version: {version}\n" \
+        .format(lines='-' * 80, version=sys.version,
+                host=host, port=port)
+
+    try:
+        # Run an interpreter
+        _run_interpreter(variables, banner)
+    finally:
+        # Stop the framework
+        framework.stop()
+
+
+def _run_interpreter(variables, banner):
+    """
+    Runs a Python interpreter console and blocks until the user exits it.
+
+    :param variables: Interpreters variables (locals)
+    :param banner: Start-up banners
+    """
+    # Script-only imports
+    import code
+    try:
+        import readline
+        import rlcompleter
+        readline.set_completer(rlcompleter.Completer(variables).complete)
+        readline.parse_and_bind("tab: complete")
+
+    except ImportError:
+        # readline is not available: ignore
+        pass
+
+    # Start the console
+    shell = code.InteractiveConsole(variables)
+    shell.interact(banner)
+
+# ------------------------------------------------------------------------------
+
+if __name__ == '__main__':
+    # Prepare arguments
+    import argparse
+    parser = argparse.ArgumentParser(description="Pelix Remote Shell")
+    parser.add_argument("-v", "--verbose", action="store_true", dest="verbose",
+                        help="Set loggers at debug level")
+    parser.add_argument("-a", "--address", dest="address", default="localhost",
+                        help="The remote shell binding address")
+    parser.add_argument("-p", "--port", dest="port", type=int, default=9000,
+                        help="The remote shell binding port")
+
+    # Parse them
+    args = parser.parse_args()
+
+    # Prepare the logger
+    if args.verbose:
+        logging.basicConfig(level=logging.DEBUG)
+    else:
+        logging.basicConfig(level=logging.WARNING)
+
+    # Run the entry point
+    main(args.address, args.port)
