@@ -6,7 +6,7 @@ Pelix Utilities: Task pool
 :author: Thomas Calmant
 :copyright: Copyright 2014, isandlaTech
 :license: Apache License 2.0
-:version: 0.5.6
+:version: 0.5.7
 :status: Beta
 
 ..
@@ -30,36 +30,73 @@ Pelix Utilities: Task pool
 __docformat__ = "restructuredtext en"
 
 # Module version
-__version_info__ = (0, 5, 6)
+__version_info__ = (0, 5, 7)
 __version__ = ".".join(str(x) for x in __version_info__)
 
 # ------------------------------------------------------------------------------
 
+# Pelix
+import pelix.utilities
+
 # Standard library
 import logging
 import threading
 
 try:
     # Python 3
+    # pylint: disable=F0401
     import queue
-
 except ImportError:
     # Python 2
+    # pylint: disable=F0401
     import Queue as queue
 
 # ------------------------------------------------------------------------------
 
+
 class FutureResult(object):
     """
     An object to wait for the result of a threaded execution
     """
-    def __init__(self):
+    def __init__(self, logger=None):
         """
         Sets up the FutureResult object
-        """
-        self._done_event = threading.Event()
-        self._result = None
 
+        :param logger: The Logger to use in case of error (optional)
+        """
+        self._logger = logger or logging.getLogger(__name__)
+        self._done_event = pelix.utilities.EventData()
+        self.__callback = None
+        self.__extra = None
+
+    def __notify(self):
+        """
+        Notify the given callback about the result of the execution
+        """
+        if self.__callback is not None:
+            try:
+                self.__callback(self._done_event.data,
+                                self._done_event.exception,
+                                self.__extra)
+            except Exception as ex:
+                self._logger.exception("Error calling back method: %s", ex)
+
+    def set_callback(self, method, extra=None):
+        """
+        Sets a callback method, called once the result has been computed or in
+        case of exception.
+
+        The callback method must have the following signature:
+        ``callback(result, exception, extra)``.
+
+        :param method: The method to call back in the end of the execution
+        :param extra: Extra parameter to be given to the callback method
+        """
+        self.__callback = method
+        self.__extra = extra
+        if self._done_event.is_set():
+            # The execution has already finished
+            self.__notify()
 
     def execute(self, method, args, kwargs):
         """
@@ -80,12 +117,17 @@ class FutureResult(object):
 
         try:
             # Call the method
-            self._result = method(*args, **kwargs)
-
+            result = method(*args, **kwargs)
+        except Exception as ex:
+            # Something went wrong: propagate to the event and to the caller
+            self._done_event.raise_exception(ex)
+            raise
+        else:
+            # Store the result
+            self._done_event.set(result)
         finally:
-            # Mark the action as executed
-            self._done_event.set()
-
+            # In any case: notify the call back (if any)
+            self.__notify()
 
     def done(self):
         """
@@ -93,7 +135,6 @@ class FutureResult(object):
         """
         return self._done_event.is_set()
 
-
     def result(self, timeout=None):
         """
         Waits up to timeout for the result the threaded job.
@@ -101,14 +142,16 @@ class FutureResult(object):
 
         :param timeout: The maximum time to wait for a result (in seconds)
         :raise OSError: The timeout raised before the job finished
+        :raise: The exception encountered during the call, if any
         """
-        if self._done_event.wait(timeout) or self._done_event.is_set():
-            return self._result
-
-        raise OSError("Timeout raised")
+        if self._done_event.wait(timeout):
+            return self._done_event.data
+        else:
+            raise OSError("Timeout raised")
 
 # ------------------------------------------------------------------------------
 
+
 class ThreadPool(object):
     """
     Executes the tasks stored in a FIFO in a thread pool
@@ -124,12 +167,15 @@ class ThreadPool(object):
         :raise ValueError: Invalid number of threads
         """
         # Validate parameters
-        if type(nb_threads) is not int or nb_threads < 1:
-            raise ValueError("Invalid pool size: {0}".format(nb_threads))
+        try:
+            nb_threads = int(nb_threads)
+            if nb_threads < 1:
+                raise ValueError("Pool size must be greater than 0")
+        except (TypeError, ValueError) as ex:
+            raise ValueError("Invalid pool size: {0}".format(ex))
 
         # The logger
-        self.__name = logname or __name__
-        self._logger = logging.getLogger(self.__name)
+        self._logger = logging.getLogger(logname or __name__)
 
         # The loop control event
         self._done_event = threading.Event()
@@ -138,7 +184,6 @@ class ThreadPool(object):
         # The task queue
         try:
             queue_size = int(queue_size)
-
         except (TypeError, ValueError):
             # Not a valid integer
             queue_size = 0
@@ -151,7 +196,6 @@ class ThreadPool(object):
         self._nb_threads = nb_threads
         self._threads = []
 
-
     def start(self):
         """
         Starts the thread pool. Does nothing if the pool is already started.
@@ -167,15 +211,14 @@ class ThreadPool(object):
         i = 0
         while i < self._nb_threads:
             i += 1
-            thread = threading.Thread(target=self.__run,
-                                      name="{0}-{1}".format(self.__name, i))
+            name = "{0}-{1}".format(self._logger.name, i)
+            thread = threading.Thread(target=self.__run, name=name)
             self._threads.append(thread)
 
         # Start'em
         for thread in self._threads:
             thread.start()
 
-
     def stop(self):
         """
         Stops the thread pool. Does nothing if the pool is already stopped.
@@ -192,20 +235,24 @@ class ThreadPool(object):
             try:
                 for _ in self._threads:
                     self._queue.put(self._done_event, True, self._timeout)
-
             except queue.Full:
                 # There is already something in the queue
                 pass
 
             # Join threads
             for thread in self._threads:
-                thread.join()
+                while thread.is_alive():
+                    # Wait 3 seconds
+                    thread.join(3)
+                    if thread.is_alive():
+                        # Thread is still alive: something might be wrong
+                        self._logger.warning("Thread %s is still alive...",
+                                             thread.name)
 
         # Clear storage
         del self._threads[:]
         self.clear()
 
-
     def enqueue(self, method, *args, **kwargs):
         """
         Enqueues a task in the pool
@@ -216,20 +263,20 @@ class ThreadPool(object):
         :raise Full: The task queue is full
         """
         if not hasattr(method, '__call__'):
-            raise ValueError("{0} has no __call__ member." \
+            raise ValueError("{0} has no __call__ member."
                              .format(method.__name__))
 
         # Prepare the future result object
-        future = FutureResult()
+        future = FutureResult(self._logger)
 
         # Use a lock, as we might be "resetting" the queue
         with self.__lock:
             # Add the task to the queue
-            self._queue.put((method, args, kwargs, future), True, self._timeout)
+            self._queue.put((method, args, kwargs, future), True,
+                            self._timeout)
 
         return future
 
-
     def clear(self):
         """
         Empties the current queue content.
@@ -241,7 +288,6 @@ class ThreadPool(object):
                 while True:
                     self._queue.get_nowait()
                     self._queue.task_done()
-
             except queue.Empty:
                 # Queue is now empty
                 pass
@@ -249,7 +295,6 @@ class ThreadPool(object):
             # Wait for the tasks currently executed
             self.join()
 
-
     def join(self, timeout=None):
         """
         Waits for all the tasks to be executed
@@ -260,19 +305,16 @@ class ThreadPool(object):
         if self._queue.empty():
             # Nothing to wait for...
             return True
-
         elif timeout is None:
             # Use the original join
             self._queue.join()
             return True
-
         else:
             # Wait for the condition
             with self._queue.all_tasks_done:
                 self._queue.all_tasks_done.wait(timeout)
                 return self._queue.empty()
 
-
     def __run(self):
         """
         The main loop
@@ -283,23 +325,20 @@ class ThreadPool(object):
                 task = self._queue.get(True, self._timeout)
                 if task is self._done_event:
                     # Stop event in the queue: get out
+                    self._queue.task_done()
                     return
-
             except queue.Empty:
                 # Nothing to do
                 pass
-
             else:
                 # Extract elements
                 method, args, kwargs, future = task
                 try:
                     # Call the method
                     future.execute(method, args, kwargs)
-
                 except Exception as ex:
                     self._logger.exception("Error executing %s: %s",
                                            method.__name__, ex)
-
                 finally:
                     # Mark the action as executed
                     self._queue.task_done()
